****NOTE: This file prepares the linked ACS and CPS data at the RDC

clear *
cap log close
cd ..
adopath+prog

*set locals
local dpath data
local lpath logs
local data acs\`s'01.dta
local ildata il0205.dta
local mddata md0204.dta

cap log close
log using "`lpath'/prepare_data.txt", text replace

foreach s in il md {
use "`dpath'/acs`s'01.dta", clear
local st=upper("`s'")
local admin fsrecip


* Sample preparation *

gen samp1=1
replace samp1=0 if age<16

gen noacsfs=1 if acsfs==0
replace noacsfs=0 if acsfs==1

gen b2xpovsamp= (hpovindex<=200) 

gen pik_b2xpovsamp = (b2xpovsamp==1 & onepik==1)

gen b2xpovsamp_noimpute = (b2xpovsamp==1 & fsimpute==0)

gen adminrecip=1 if pik_b2xpovsamp==1 & fsrecip==1
replace adminrecip=0 if adminrecip==.

gen adminnorecip=1 if pik_b2xpovsamp==1 & fsrecip==0
replace adminnorecip=0 if adminnorecip==.

gen age17_29=1 if age10_19==1|age20_29==1
replace age17_29=0 if age10_19==0 & age20_29==0

gen povindex_2=hpovindex^2
gen povindex_3=hpovindex^3
gen povindex_4=hpovindex^4
gen povindex_5=hpovindex^5

replace fsnummos=0 if `admin'==0

*Correct weights for PIK rate*

probit onepik sing0kid singwkid mar0kid numlt18 numge18 age17_29 age30_39 age50_59 age60_69 age_ge70 lths hs ge_col hh_hisp hh_nhblk hh_nhoth unemped nolabfor hpovindex disabled disnowrk engonly engpoor hhnoncit cati capi rural rentasst if samp1==1 [pweight=wgt], nocoef
predict p if e(pik_sample)

margins, dydx(_all) post
outreg2 using tables/pik_analysis_acs_`s', excel replace title(Determinants of PIKing, ACS `st', Avg der) ctitle(`st' ACS) se bdec(4) sdec(4) noaster

gen nonresp_wgt=1/p
gen total_wgt=wgt*nonresp_wgt
gen total_hpwgt=hpwgt*nonresp_wgt
summarize total_wgt if b2xpovsamp==1
gen nb2xptot_wgt=(total_wgt/r(sum))*r(N)
summarize wgt if b2xpovsamp==1
gen nb2xpsvy_wgt=(wgt/r(sum))*r(N)

save `dpath'/analysis_acs_`s'.dta, replace



**CPS

use "`dpath'/``s'data'", clear
local admin fsad_cpshh
local survey fscps

*prepare data (from Janna's probit_il.do file)
cap label var hhid "Unique HH ID - Concat of h_year & ph_seq"
cap label var ppid "Unique PP ID - Concat of h_year, ph_seq & ppposold"


*drop group quarters ppl
drop if hhdrel==8

*family type
*Number of adults in HH
gen hover18 = h_numper - hunder18

*Single adult HH indicator
gen sing0kid = (hover18==1 & hunder18==0)

*Single adult w/kids HH indicator
gen singwkid = (hover18==1 & hunder18>0)

*Multiple adult HH no kids indicator
gen multad0kid = (hover18>1 & hunder18==0)

*Multiple adult HH w kids indicator 
gen multadwkid = (hover18>1 & hunder18>0)

* Number of members PIKed

sort hhid
by hhid: egen numwpik = total(haspik)

* All of the following are based off of the householder (person for which hhlder==1).  
* Age categories

* Keep only HHs with head 16 YO or older
gen yghhlder = (hhlder==1 & a_age<16)
by hhid: egen young = max(yghhlder)
list a_age hhid ppid hhdrel hhlder if young==1
drop if young==1


gen hhlderag = a_age if hhlder==1
by hhid: egen hhlderage = max(hhlderag)
drop hhlderag

by hhid: gen age15_29 = (hhlderage<30)
by hhid: gen age30_39 = (hhlderage<40 & hhlderage>29)
by hhid: gen age40_49 = (hhlderage<50 & hhlderage>39)
by hhid: gen age50_59 = (hhlderage<60 & hhlderage>49)
by hhid: gen age60_69 = (hhlderage<70 & hhlderage>59)
by hhid: gen age_ge70 = (hhlderage>69)
by hhid: gen age_ge50 = (hhlderage>=50)

* Education categories

gen ehhlder= a_hga if hhlder==1
by hhid: egen hhldereduc = max(ehhlder)
drop ehhlder

by hhid: gen lths = (hhldereduc<39)
by hhid: gen hsgrad = (hhldereduc==39)
by hhid: gen somecol = (hhldereduc>39 & hhldereduc<43)
by hhid: gen colgradplus = (hhldereduc>42)

* Race categories

*Note: black category is for non-Hispanic blacks only.  Black hispanics are in Hispanic category

gen rhhlder = rac_hisp if hhlder==1
by hhid: egen hhlderrace = max(rhhlder)
drop rhhlder

by hhid: gen white = (hhlderrace==1)
by hhid: gen hispanic = (hhlderrace==2 | hhlderrace==4 | hhlderrace==6)
by hhid: gen black = (hhlderrace==3)
by hhid: gen other = (hhlderrace==5)

by hhid: gen nonwhite = (hhlderrace!=1)

* Labor force categories

gen lhhlder = a_lfsr if hhlder==1
by hhid: egen hhlderlfs = max(lhhlder)
drop lhhlder

by hhid: gen employed = (hhlderlfs>0 & hhlderlfs<3)
by hhid: gen unemployed =  (hhlderlfs>2 & hhlderlfs<5)
by hhid: gen nilf = (hhlderlfs>4 | hhlderlfs==0)

* Disabled indicator - use CPS question about ANYONE in HH has disability

*CPS disabled question basis
gen disabled = (hdis_yn==1)

* MSA status

*NOTE: GEOGRAPHIC AREA VARIABLES ARE NAMED DIFFERENTLY IN 2005 DATA VS. EARLIER
*MSA vs. rural
gen msa = (reside<11)
if "`s'"=="il" replace msa = (gecbsast==1 | gecbsast==2) if h_year==2005
gen rural = (reside>10)
if "`s'"=="il" replace rural = (gecbsast==3) if h_year==2005

*MSA cent vs. MSA ring vs. rural
gen msacent = (reside==1 |reside==3 | reside==5 | reside==7 | reside==9)
if "`s'"=="il" replace msacent = (gecbsast==1) if h_year==2005
gen msaring = (reside==2 |reside==4 | reside==6 | reside==8 | reside==10)
if "`s'"=="il" replace msaring = (gecbsast==2) if h_year==2005

* PAW receipt - CPS reported

gen paw = (hpaw_yn==1)

* Housing assistance receipt - CPS reported*

gen housing = (hpublic==1 | hlorent==1)

* Food stamp receipt imputed indicator

gen fsimpute = (i_hfoods==1)

* Number of months in year receiving FS is variable called "FSNUMMOS"
* TANF Administrative receipt indicator is "TANFAD_CPSHH"

* Male householder
gen malehh = (a_sex==1 & hhlder==1)
by hhid: egen malehhlder = max(malehh)
drop malehh

* Linear Time Trend
gen trend = h_year-2000

* Bottom code povindex
replace povindex=0 if povindex<0
gen povindex_2=povindex^2
gen povindex_3=povindex^3
gen povindex_4=povindex^4
gen povindex_5=povindex^5

*no fs report
gen noreport = (`survey'==0)

* Adjust weights for PIK rate
tab hhpiked

probit hhpiked sing0kid singwkid multad0kid hunder18 hover18 age15_29 age30_39 age50_59 age60_69 age_ge70 lths hsgrad colgradplus hispanic black other unemployed nilf povindex disabled rural housing trend if hhlder==1 [pw=hhwgt], nocoef
predict p if e(sample)
margins, dydx(_all) post
outreg2 using tables/pik_analysis_cps_`s', excel replace se title(The Determinants of PIKing, AVG DER, CPS `st') ctitle(`st' CPS) bdec(4) sdec(4) noaster

gen adj = 1/p
gen adjwt = hhwgt*adj

save `dpath'/analysis_cps_`s'.dta, replace

}

*ACS
*pool MD, IL
use `dpath'/analysis_acs_il.dta, clear
append using `dpath'/analysis_acs_md.dta, gen(maryld) nol
save `dpath'/analysis_acs.dta, replace
local admin fsrecip
*get summary statistics
di "Weighted Summary Statistics"
sum `admin' acsfs hpovindex povindex_* age_ge50 maryld fsimpute noacsfs [aw=total_wgt] if b2xpovsamp==1 & total_wgt!=. & onepik==1
di "Unweighted Summary Statistics"
sum `admin' acsfs hpovindex povindex_* age_ge50 maryld fsimpute noacsfs if b2xpovsamp==1 & total_wgt!=. & onepik==1

di "crosstabs of age_ge50 and maryland dummy with dependent variables used in models of misreporting (used in tables 6 and 12)"
tab noacsfs age_ge50 if adminnorecip==1 & total_wgt!=. & onepik==1
tab noacsfs maryld if adminnorecip==1 & total_wgt!=. & onepik==1
tab acsfs age_ge50 if adminrecip==1 & total_wgt!=. & onepik==1
tab acsfs maryld if adminrecip==1 & total_wgt!=. & onepik==1
di "crosstabs of age_ge50 and maryland dummy with dependent variables used in models of food stamp receipt"
di "used in table 7 col 7-9 and table 9 col 3-4 as well as implicitly in tables 2&4 and 12"
tab `admin' age_ge50 if b2xpovsamp==1 & total_wgt!=. & onepik==1
tab `admin' maryld if b2xpovsamp==1 & total_wgt!=. & onepik==1
di "these crosstabs only contain public use data and are used in table 7, col 1-5, table 9 col 1-2 and in tables 11 and 13"
tab acsfs age_ge50 if b2xpovsamp==1 & total_wgt!=. & onepik==1
tab acsfs maryld if b2xpovsamp==1 & total_wgt!=. & onepik==1
di "crosstabs used in table 13, column 7"
tab acsfs age_ge50 if b2xpovsamp==1 & total_wgt!=. & onepik==1 & maryld==1
tab acsfs maryld if b2xpovsamp==1 & total_wgt!=. & onepik==1 & maryld==1
tab noacsfs age_ge50 if adminnorecip==1 & total_wgt!=. & onepik==1 & maryld==0
tab noacsfs maryld if adminnorecip==1 & total_wgt!=. & onepik==1 & maryld==0
tab acsfs age_ge50 if adminrecip==1 & total_wgt!=. & onepik==1 & maryld==0
tab acsfs maryld if adminrecip==1 & total_wgt!=. & onepik==1 & maryld==0

di "Crosstabs that generate the probabilities of fales positives and negatives used in models mms and mg"
svyset [pw=total_wgt]
di "pr false positives is in 2nd col, 3rd row; pr false negatives from first col, 8th row"
svy: tab fsrecip acsfs if b2xpovsamp==1 & total_wgt!=. & onepik==1, format(%13.4g) count row col cell obs
di "calculates pr false negatives as in meyer, mok and sullivan on sample used in estimation"
sum fsrecip [aw=total_wgt] if b2xpovsamp==1 & total_wgt!=. & onepik==1
local a=r(mean)
sum acsfs  [aw=total_wgt] if b2xpovsamp==1 & total_wgt!=. & onepik==1
di "Pr false negatives: " (`a'-r(mean))/`a'

*CPS
*pool MD, IL
use `dpath'/analysis_cps_il.dta, clear
append using `dpath'/analysis_cps_md.dta, gen(maryld) nol
save `dpath'/analysis_cps.dta, replace
local admin fsad_cpshh
local survey fscps

*get summary statistics
di "Weighted Summary Statistics"
sum `admin' `survey' povindex* age_ge50 maryld fsimpute noreport [aw=adjwt] if povindex<=200 & hhlder==1 & adjwt!=. & hhpiked==1
di "Unweighted Summary Statistics"
sum `admin' `survey' povindex* age_ge50 maryld fsimpute noreport if povindex<=200 & hhlder==1 & adjwt!=. & hhpiked==1

di "crosstabs of age_ge50 and maryland dummy with dependent variables used in models of misreporting (used in tables 6 and 12)"
tab noreport age_ge50 if povindex<=200 & `admin'==1 & hhlder==1 & hhpiked==1 & adjwt!=.
tab noreport maryld if povindex<=200 & `admin'==1 & hhlder==1 & hhpiked==1 & adjwt!=.
tab `survey' age_ge50 if povindex<=200 & `admin'==0 & hhlder==1 & hhpiked==1 & adjwt!=.
tab `survey' maryld if povindex<=200 & `admin'==0 & hhlder==1 & hhpiked==1 & adjwt!=.
di "crosstabs of age_ge50 and maryland dummy with dependent variables used in models of food stamp receipt"
di "used in table 8 col 7-9 and table 10 col 3-4 as well as implicitly in tables 3&5 and 12"
tab `admin' age_ge50 if povindex<=200 & hhlder==1 & adjwt!=. & hhpiked==1
tab `admin' maryld if povindex<=200 & hhlder==1 & adjwt!=. & hhpiked==1
di "these crosstabs only contain public use data and are used in table 8, col 1-5, table 10 col 1-2 and in tables 12 and 13"
tab `survey' age_ge50 if povindex<=200 & hhlder==1 & adjwt!=. & hhpiked==1
tab `survey' maryld if povindex<=200 & hhlder==1 & adjwt!=. & hhpiked==1

di "Crosstabs that generate the probabilities of fales positives and negatives used in subsequent .do files (in models mms and mg)"
svyset [pw=adjwt]
di "pr false positives is in 2nd col, 3rd row; pr false negatives from first col, 8th row"
svy: tab `admin' `survey' if povindex<=200 & hhlder==1 & hhpiked==1 & adjwt!=., format(%13.4g) count row col cell obs
di "calculates pr false negatives as in meyer, mok and sullivan on sample used in estimation"
sum `admin' [aw=adjwt] if povindex<=200 & hhlder==1 & hhpiked==1
local a=r(mean)
sum `survey'  [aw=adjwt] if povindex<=200 & hhlder==1 & hhpiked==1
di "Pr false negatives: " (`a'-r(mean))/`a'

cap log close

