****NOTE: This file runs the analyses in part 4.1 of "Misclassification in Binary Choice Models". There are several versions of 02_mc_random_mr.do to allow running the simulations for different estimators in parallel (this used to be slow at the RDC).

clear *
cap log close
set maxiter 500
set matsize 1000
cd ..
adopath+prog
global Samp samp

**ACS 
*set locals
local dpath data
local lpath logs
local iter=500

*food stamp variable
local survey acsfs
local admin fsrecip

*imputation variable
local impute fsimpute

*weight 
local weight wgt
local adjwgt total_wgt

*covariates for false negatives
local fneg "hpovindex povindex_2 povindex_3 age_ge50 maryld"

*covariates for false positives
local fpos "hpovindex povindex_2 age_ge50 maryld"

*cells for alpha
local a0cells fsimpute
local a1cells age_ge50

*covariates for receipt
local rec "hpovindex age_ge50 maryld"

di "The numbers below are obtained from crosstabs in 01_prepare_data.do (after summary statistics)"
*in actual sample
local a1mms=
local a0mgimp=
local a1mgimp=

cap log close
log using "`lpath'/acs_mc.txt", text replace
use "`dpath'/analysis_acs.dta", clear

foreach samp in pikd {
matrix drop _all

if "`samp'"=="full" {
local sample "Full Sample"
local if ""
local imp "imp"
local weight wgt
}
if "`samp'"=="nimp" {
local sample "Non-Imputed Sample"
local if "& `impute'==0"
local imp "nimp"
local weight wgt
}

if "`samp'"=="pikd" {
local sample "Piked Sample"
local if "& onepik==1"
local imp "imp"
local weight "`adjwgt'"
}

if "`samp'"=="pikdnimp" {
local sample "Non-Imputed and Piked Sample"
local if "& `impute'==0 & onepik==1"
local imp "nimp"
local weight "`adjwgt'"
}

*run MC study
gen mr_admin=`admin'
gen rand=.
gen adminrecip_mc=.
gen adminnorecip_mc=.
gen noacsfs_mc=.
gen me_mc=.

*get "true" values
*Probit on administrative data
probit `admin' `rec' [pw=`adjwgt'] if pik_b2xpovsamp==1
mat def ad=e(b)
mat coleq ad=Probit

*ratios of coef
mat def ratad=(nullmat(ratad)\ad[1,1..(colsof(ad)-1)]/ad[1,1])
*margins
margins, dydx(_all) post
mat def mfad=e(b)

*LPM on administrative data
reg `admin' `rec' [pw=`adjwgt'] if pik_b2xpovsamp==1
mat def lpma=e(b)
*ratios of coef
mat def ratlpma=(nullmat(ratlpma)\lpma[1,1..(colsof(lpma)-1)]/lpma[1,1])

local i=1
while `i'<=`iter' {
if mod(`i',10)==0 di "iteration `i'"

***setup
*induce random misreporting
*qui {
replace rand=runiform()
replace mr_admin=`admin'
replace mr_admin=1 if `admin'==0 & rand<`a0mg`imp''
replace mr_admin=0 if `admin'==1 & rand<`a1mg`imp''

replace adminrecip_mc=0
replace adminrecip_mc=1 if pik_b2xpovsamp==1 & `admin'==1

replace adminnorecip_mc=0
replace adminnorecip_mc=1 if pik_b2xpovsamp==1 & `admin'==0

replace noacsfs_mc=1 if mr_admin==0
replace noacsfs_mc=0 if mr_admin==1

replace me_mc=mr_admin-`admin' if pik_b2xpovsamp==1

*get probabilities of fneg/fpos to integrate them out
*fneg
probit noacsfs_mc `fneg' [pw=`weight'] if adminrecip_mc==1 `if'
predict pr_fn, pr
sum pr_fn, d

*fpos
probit mr_admin `fpos' [pw=`weight'] if adminnorecip_mc==1 `if'
predict pr_fp, pr
sum pr_fp, d

***run models
*Probit on Survey data
probit mr_admin `rec' [pw=`weight'] if b2xpovsamp==1 `if'
mat def a=e(b)
capture mat def sv=(nullmat(sv)\a)
if _rc!=0 mat def failure=(nullmat(failure)\(`i',1,_rc))
*ratios of coefficients (ratio to first coef)
capture mat def rat=(nullmat(rat)\a[1,1..(colsof(a)-1)]/a[1,1])
if _rc!=0 mat def failure=(nullmat(failure)\(`i',2,_rc))
*scaled up marginal effects
margins, dydx(_all) post
mat def a=e(b)
capture mat def sc=(nullmat(sc)\a/(1-`a0mg`imp''-`a1mg`imp''))
if _rc!=0 mat def failure=(nullmat(failure)\(`i',3,_rc))

*Hausman Probit
capture noisily mrprobit mr_admin `rec' [pw=`weight'] if b2xpovsamp==1 `if', maxopts(difficult) modelopts(technique(dfp bfgs nr bhhh))
if _rc==0 & e(converged)==1 capture mat def hp=(nullmat(hp)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',4,_rc))

*Hausman Probit with alpha0=0 and alpha1 from Meyer, Mok, Sullivan
capture noisily mrprobit mr_admin `rec' [pw=`weight'] if b2xpovsamp==1 `if', alpha0(0) alpha1(`a1mms')
if _rc==0 & e(converged)==1 capture mat def mms=(nullmat(mms)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',5,_rc))

*Hausman Probit with alphas from MG
capture noisily mrprobit mr_admin `rec' [pw=`weight'] if b2xpovsamp==1 `if', alpha0(`a0mg`imp'') alpha1(`a1mg`imp'')
if _rc==0 & e(converged)==1 capture mat def mg=(nullmat(mg)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',6,_rc))

*cells for alphas
capture noisily mrprobit mr_admin `rec' [pw=`weight'] if b2xpovsamp==1 `if', alpha0(`a0cells') alpha1(`a1cells') maxopts(difficult) modelopts(technique(dfp bfgs nr bhhh))
if _rc==0 & e(converged)==1 capture mat def cl=(nullmat(cl)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',7,_rc))

*predicted probabilities
capture noisily mrprobit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 `if', alpha0(pr_fp) alpha1(pr_fn)
if _rc==0 & e(converged)==1 capture mat def pp=(nullmat(pp)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',8,_rc))

*joint estimator without common obs
gen tmp=runiform()
qui: sum tmp, d
gen samp=(tmp<r(p50)) if b2xpovsamp==1 `if'
recode samp (0=3)
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 `if'  [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc==0 capture mat def jno=(nullmat(jno)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',9,_rc))

*joint estimator with common obs
recode samp (1=2)
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 `if' [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc==0 capture mat def jva=(nullmat(jva)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',10,_rc))
drop tmp samp

****LPM
*uncorrected LPM
reg mr_admin `rec' [pw=`weight'] if b2xpovsamp==1 `if'
mat def a=e(b)
capture mat def lpmsv=(nullmat(lpmsv)\a)
if _rc!=0 mat def failure=(nullmat(failure)\(`i',11,_rc))
*ratios of coefficients (ratio to first coef)
capture mat def lpmrat=(nullmat(lpmrat)\a[1,1..(colsof(a)-1)]/a[1,1])
if _rc!=0 mat def failure=(nullmat(failure)\(`i',12,_rc))
*scaled up coefficients
capture mat def lpmsc=(nullmat(lpmsc)\a[1,1..(colsof(a)-1)]/(1-`a0mg`imp''-`a1mg`imp''))
if _rc!=0 mat def failure=(nullmat(failure)\(`i',13,_rc))

*corrected LPM
reg me_mc `rec' [pw=`adjwgt'] if b2xpovsamp==1 `if'
mat def corr=e(b)
capture mat def lpmc=(nullmat(lpmc)\a-corr)
if _rc!=0 mat def failure=(nullmat(failure)\(`i',14,_rc))

*clean up
drop pr_fp pr_fn
local i=`i'+1
*}
}
*show failures
capture noisily mat list failure

*get number of succesful iterations
foreach x in sv sc rat hp mms mg cl pp jno jva lpmsv lpmrat lpmsc lpmc {
local i=rowsof(`x')
di "Successful iterations `x': " `i'
}


*calculate bias and mse
foreach x in sv mms mg cl pp jno jva {
*bias
capture noisily mata: st_matrix("bias_`x'",colsum(st_matrix(st_local("x"))[1...,1..cols(st_matrix("ad"))]:-st_matrix("ad"))/rows(st_matrix(st_local("x"))))
*mse
capture noisily mata: st_matrix("mse_`x'",colsum((st_matrix(st_local("x"))[1...,1..cols(st_matrix("ad"))]:-st_matrix("ad")):^2)/rows(st_matrix(st_local("x"))))
}

*bias
capture noisily mata: st_matrix("bias_hp",colsum(st_matrix("hp"):-(st_matrix("ad"),`a0mg`imp'',`a1mg`imp''))/rows(st_matrix("hp")))
capture noisily mata: st_matrix("bias_rat",colsum(st_matrix("rat"):-st_matrix("ratad"))/rows(st_matrix("rat")))
capture noisily mata: st_matrix("bias_sc",colsum(st_matrix("sc"):-st_matrix("mfad"))/rows(st_matrix("sc")))
*mse
capture noisily mata: st_matrix("mse_hp",colsum((st_matrix("hp"):-(st_matrix("ad"),`a0mg`imp'',`a1mg`imp'')):^2)/rows(st_matrix("hp")))
capture noisily mata: st_matrix("mse_rat",colsum((st_matrix("rat"):-st_matrix("ratad")):^2)/rows(st_matrix("rat")))
capture noisily mata: st_matrix("mse_sc",colsum((st_matrix("sc"):-st_matrix("mfad")):^2)/rows(st_matrix("sc")))

foreach x in lpmsv lpmsc lpmc {
*bias
capture noisily mata: st_matrix("bias_`x'",colsum(st_matrix(st_local("x")):-st_matrix("lpma")[1,1..cols(st_matrix(st_local("x")))])/rows(st_matrix(st_local("x"))))
*mse
capture noisily mata: st_matrix("mse_`x'",colsum((st_matrix(st_local("x")):-st_matrix("lpma")[1,1..cols(st_matrix(st_local("x")))]):^2)/rows(st_matrix(st_local("x"))))
}

*bias
capture noisily mata: st_matrix("bias_lpmrat",colsum(st_matrix("lpmrat"):-st_matrix("ratlpma"))/rows(st_matrix("lpmrat")))
*mse
capture noisily mata: st_matrix("mse_lpmrat",colsum((st_matrix("lpmrat"):-st_matrix("ratlpma")):^2)/rows(st_matrix("lpmrat")))

*count fraction of sv coefficients attenuated & % attenuated if attenuated
di "Fraction of survey coef attenuated"
capture noisily mata: st_matrix("frac_att",colsum((abs(st_matrix("ad")[1...,1..(cols(st_matrix("ad"))-1)]):>abs(st_matrix("sv")[1...,1..(cols(st_matrix("ad"))-1)])))/rows(st_matrix("sv")))
di "average attenuation (in %) if attenuated"
capture noisily mata: a=(abs(st_matrix("ad")[1...,1..(cols(st_matrix("ad"))-1)]):>abs(st_matrix("sv")[1...,1..(cols(st_matrix("ad"))-1)]))
mata: b=J(1,cols(st_matrix("ad"))-1,.)
local i=1
while `i'<=colsof(sv)-1 {
capture noisily mata: b[1,`i']=mean(1:-(select(st_matrix("sv")[1...,`i'],a[1...,`i']):/st_matrix("ad")[1,`i']))
local i=`i'+1
}
capture noisily mata: st_matrix("degr_att",b)

*write file
file open results using tables/mc_uncacs_`samp'.txt, write text replace
foreach x in sv rat sc hp mms mg cl pp lpmsv lpmrat lpmsc lpmc {
file write results "bias `x'"
local i=1
capture noisily {
while `i'<=colsof(bias_`x') {
local val=bias_`x'[1,`i']
file write results ", `val'" 
local i=`i'+1
}
}
file write results _n
file write results "mse `x'"
local i=1
capture noisily {
while `i'<=colsof(mse_`x') {
local val=mse_`x'[1,`i']
file write results ", `val'"
local i=`i'+1
}
}
file write results _n
}
foreach x in frac degr {
file write results "`x'_att"
local i=1
capture noisily {
while `i'<=colsof(`x'_att) {
local val=`x'_att[1,`i']
file write results ", `val'"
local i=`i'+1
}
}
file write results _n
}
file close results
}


**CPS
*set locals
*food stamp variable
local survey fscps
local admin fsad_cpshh

*imputation variable
local impute fsimpute

*weight 
local weight hhwgt
local adjwgt adjwt

*covariates for false negatives
local fneg "povindex age_ge50 maryld"

*covariates for false positives
local fpos "povindex age_ge50 maryld"

*cells for alpha
local a0cells fsimpute
local a1cells age_ge50

*covariates for receipt
local rec "povindex age_ge50 maryld"

di "The numbers below are obtained from crosstabs in 01_prepare_data.do (after summary statistics)"
*alphas from admin data
*in actual sample
local a1mms=
local a0mgimp=
local a1mgimp=

cap log close
log using "`lpath'/cps_mc.txt", text replace
use "`dpath'/analysis_cps.dta", clear

foreach samp in pikd {
matrix drop _all

if "`samp'"=="full" {
local sample "Full Sample"
local if ""
local imp "imp"
local weight hhwgt
}
if "`samp'"=="nimp" {
local sample "Non-Imputed Sample"
local if "& `impute'==0"
local imp "nimp"
local weight hhwgt
}

if "`samp'"=="pikd" {
local sample "Piked Sample"
local if "& hhpiked==1"
local imp "imp"
local weight "`adjwgt'"
}

if "`samp'"=="pikdnimp" {
local sample "Non-Imputed and Piked Sample"
local if "& `impute'==0 & hhpiked==1"
local imp "nimp"
local weight "`adjwgt'"
}

*run MC study
gen mr_admin=`admin'
gen rand=.
gen adminrecip_mc=.
gen adminnorecip_mc=.
gen noacsfs_mc=.
gen me_mc=.

*get "true" values
*Probit on administrative data
probit `admin' `rec' [pw=`adjwgt'] if povindex<=200 & hhlder==1 & hhpiked==1
mat def ad=e(b)
mat coleq ad=Probit

*ratios of coef
mat def ratad=(nullmat(ratad)\ad[1,1..(colsof(ad)-1)]/ad[1,1])
*margins
margins, dydx(_all) post
mat def mfad=e(b)

*LPM on administrative data
reg `admin' `rec' [pw=`adjwgt'] if povindex<=200 & hhlder==1 & hhpiked==1
mat def lpma=e(b)
*ratios of coef
mat def ratlpma=(nullmat(ratlpma)\lpma[1,1..(colsof(lpma)-1)]/lpma[1,1])

local i=1
while `i'<=`iter' {
if mod(`i',10)==0 di "iteration `i'"

***setup
*induce random misreporting
*qui {
replace rand=runiform()
replace mr_admin=`admin'
replace mr_admin=1 if `admin'==0 & rand<`a0mg`imp''
replace mr_admin=0 if `admin'==1 & rand<`a1mg`imp''

replace adminrecip_mc=0
replace adminrecip_mc=1 if povindex<=200 & hhlder==1 & hhpiked==1 & `admin'==1

replace adminnorecip_mc=0
replace adminnorecip_mc=1 if povindex<=200 & hhlder==1 & hhpiked==1 & `admin'==0

replace noacsfs_mc=1 if mr_admin==0
replace noacsfs_mc=0 if mr_admin==1

replace me_mc=mr_admin-`admin' if povindex<=200 & hhlder==1 & hhpiked==1

*get probabilities of fneg/fpos to integrate them out
*fneg
probit noacsfs_mc `fneg' [pw=`weight'] if adminrecip_mc==1 `if'
predict pr_fn, pr
sum pr_fn, d

*fpos
probit mr_admin `fpos' [pw=`weight'] if adminnorecip_mc==1 `if'
predict pr_fp, pr
sum pr_fp, d

***run models
*Probit on Survey data
probit mr_admin `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if'
mat def a=e(b)
capture mat def sv=(nullmat(sv)\a)
if _rc!=0 mat def failure=(nullmat(failure)\(`i',1,_rc))
*ratios of coefficients (ratio to first coef)
capture mat def rat=(nullmat(rat)\a[1,1..(colsof(a)-1)]/a[1,1])
if _rc!=0 mat def failure=(nullmat(failure)\(`i',2,_rc))
*scaled up marginal effects
margins, dydx(_all) post
mat def a=e(b)
capture mat def sc=(nullmat(sc)\a/(1-`a0mg`imp''-`a1mg`imp''))
if _rc!=0 mat def failure=(nullmat(failure)\(`i',3,_rc))

*Hausman Probit
capture noisily mrprobit mr_admin `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', maxopts(difficult) modelopts(technique(dfp bfgs nr bhhh))
if _rc==0 & e(converged)==1 capture mat def hp=(nullmat(hp)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',4,_rc))

*Hausman Probit with alpha0=0 and alpha1 from Meyer, Mok, Sullivan
capture noisily mrprobit mr_admin `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', alpha0(0) alpha1(`a1mms') init(ad)
if _rc==0 & e(converged)==1 capture mat def mms=(nullmat(mms)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',5,_rc))

*Hausman Probit with alphas from MG
capture noisily mrprobit mr_admin `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', alpha0(`a0mg`imp'') alpha1(`a1mg`imp'')
if _rc==0 & e(converged)==1 capture mat def mg=(nullmat(mg)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',6,_rc))

*cells for alphas
capture noisily mrprobit mr_admin `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', alpha0(`a0cells') alpha1(`a1cells') maxopts(difficult) modelopts(technique(dfp bfgs nr bhhh))
if _rc==0 & e(converged)==1 capture mat def cl=(nullmat(cl)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',7,_rc))

*predicted probabilities
capture noisily mrprobit `survey' `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', alpha0(pr_fp) alpha1(pr_fn)
if _rc==0 & e(converged)==1 capture noisily mat def pp=(nullmat(pp)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',8,_rc))

*Joint estimator with no overlapp
gen tmp=runiform()
qui: sum tmp, d
gen samp=(tmp<r(p50)) if povindex<=200 & hhlder==1 `if'
recode samp (0=3)
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if povindex<=200 & hhlder==1 `if' [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc==0 capture mat def jno=(nullmat(jno)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',9,_rc))

recode samp (1=2)
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if povindex<=200 & hhlder==1 `if' [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc==0 capture mat def jva=(nullmat(jva)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',10,_rc))
drop tmp samp



****LPM
*uncorrected LPM
reg mr_admin `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if'
mat def a=e(b)
capture mat def lpmsv=(nullmat(lpmsv)\a)
if _rc!=0 mat def failure=(nullmat(failure)\(`i',11,_rc))
*ratios of coefficients (ratio to first coef)
capture mat def lpmrat=(nullmat(lpmrat)\a[1,1..(colsof(a)-1)]/a[1,1])
if _rc!=0 mat def failure=(nullmat(failure)\(`i',12,_rc))
*scaled up coefficients
capture mat def lpmsc=(nullmat(lpmsc)\a[1,1..(colsof(a)-1)]/(1-`a0mg`imp''-`a1mg`imp''))
if _rc!=0 mat def failure=(nullmat(failure)\(`i',13,_rc))

*corrected LPM
reg me_mc `rec' [pw=`adjwgt'] if povindex<=200 & hhlder==1 `if'
mat def corr=e(b)
capture mat def lpmc=(nullmat(lpmc)\a-corr)
if _rc!=0 mat def failure=(nullmat(failure)\(`i',14,_rc))

*clean up
drop pr_fp pr_fn
local i=`i'+1
*}
}

*show failures
capture noisily mat list failure
*get number of succesful iterations
foreach x in sv sc rat hp mms mg cl pp jno jva lpmsv lpmrat lpmsc lpmc {
local i=rowsof(`x')
di "Successful iterations `x': " `i'
}

*calculate bias and mse
foreach x in sv mms mg cl pp jno jva {
*bias
capture noisily mata: st_matrix("bias_`x'",colsum(st_matrix(st_local("x"))[1...,1..cols(st_matrix("ad"))]:-st_matrix("ad"))/rows(st_matrix(st_local("x"))))
*mse
capture noisily mata: st_matrix("mse_`x'",colsum((st_matrix(st_local("x"))[1...,1..cols(st_matrix("ad"))]:-st_matrix("ad")):^2)/rows(st_matrix(st_local("x"))))
}

*bias
capture noisily mata: st_matrix("bias_hp",colsum(st_matrix("hp"):-(st_matrix("ad"),`a0mg`imp'',`a1mg`imp''))/rows(st_matrix("hp")))
capture noisily mata: st_matrix("bias_rat",colsum(st_matrix("rat"):-st_matrix("ratad"))/rows(st_matrix("rat")))
capture noisily mata: st_matrix("bias_sc",colsum(st_matrix("sc"):-st_matrix("mfad"))/rows(st_matrix("sc")))
*mse
capture noisily mata: st_matrix("mse_hp",colsum((st_matrix("hp"):-(st_matrix("ad"),`a0mg`imp'',`a1mg`imp'')):^2)/rows(st_matrix("hp")))
capture noisily mata: st_matrix("mse_rat",colsum((st_matrix("rat"):-st_matrix("ratad")):^2)/rows(st_matrix("rat")))
capture noisily mata: st_matrix("mse_sc",colsum((st_matrix("sc"):-st_matrix("mfad")):^2)/rows(st_matrix("sc")))

foreach x in lpmsv lpmsc lpmc {
*bias
capture noisily mata: st_matrix("bias_`x'",colsum(st_matrix(st_local("x")):-st_matrix("lpma")[1,1..cols(st_matrix(st_local("x")))])/rows(st_matrix(st_local("x"))))
*mse
capture noisily mata: st_matrix("mse_`x'",colsum((st_matrix(st_local("x")):-st_matrix("lpma")[1,1..cols(st_matrix(st_local("x")))]):^2)/rows(st_matrix(st_local("x"))))
}

*bias
capture noisily mata: st_matrix("bias_lpmrat",colsum(st_matrix("lpmrat"):-st_matrix("ratlpma"))/rows(st_matrix("lpmrat")))
*mse
capture noisily mata: st_matrix("mse_lpmrat",colsum((st_matrix("lpmrat"):-st_matrix("ratlpma")):^2)/rows(st_matrix("lpmrat")))

*count fraction of sv coefficients attenuated & % attenuated if attenuated
di "Fraction of survey coef attenuated"
capture noisily mata: st_matrix("frac_att",colsum((abs(st_matrix("ad")[1...,1..(cols(st_matrix("ad"))-1)]):>abs(st_matrix("sv")[1...,1..(cols(st_matrix("ad"))-1)])))/rows(st_matrix("sv")))
di "average attenuation (in %) if attenuated"
capture noisily mata: a=(abs(st_matrix("ad")[1...,1..(cols(st_matrix("ad"))-1)]):>abs(st_matrix("sv")[1...,1..(cols(st_matrix("ad"))-1)]))
mata: b=J(1,cols(st_matrix("ad"))-1,.)
local i=1
while `i'<=colsof(sv)-1 {
capture noisily mata: b[1,`i']=mean(1:-(select(st_matrix("sv")[1...,`i'],a[1...,`i']):/st_matrix("ad")[1,`i']))
local i=`i'+1
}
capture noisily mata: st_matrix("degr_att",b)

*write file
file open results using tables/mc_unccps_`samp'.txt, write text replace
foreach x in sv rat sc hp mms mg cl pp lpmsv lpmrat lpmsc lpmc {
file write results "bias `x'"
local i=1
capture noisily {
while `i'<=colsof(bias_`x') {
local val=bias_`x'[1,`i']
file write results ", `val'" 
local i=`i'+1
}
}
file write results _n
file write results "mse `x'"
local i=1
capture noisily {
while `i'<=colsof(mse_`x') {
local val=mse_`x'[1,`i']
file write results ", `val'"
local i=`i'+1
}
}
file write results _n
}
foreach x in frac degr {
file write results "`x'_att"
local i=1
capture noisily {
while `i'<=colsof(`x'_att) {
local val=`x'_att[1,`i']
file write results ", `val'"
local i=`i'+1
}
}
file write results _n
}
file close results
}


