****NOTE: This file runs the analyses in part 4.1 of "Misclassification in Binary Choice Models". There are several versions of 02_mc_random_mr.do to allow running the simulations for different estimators in parallel (this used to be slow at the RDC).

clear *
cap log close
set maxiter 500
set matsize 1000
cd ..
adopath+prog
global Samp samp

**ACS 
*set locals
local dpath data
local lpath logs
local iter=500

*food stamp variable
local survey acsfs
local admin fsrecip

*imputation variable
local impute fsimpute

*weight 
local weight wgt
local adjwgt total_wgt

*covariates for false negatives
local fneg "hpovindex povindex_2 povindex_3 age_ge50 maryld"

*covariates for false positives
local fpos "hpovindex povindex_2 age_ge50 maryld"

*cells for alpha
local a0cells fsimpute
local a1cells age_ge50

*covariates for receipt
local rec "hpovindex age_ge50 maryld"

di "The numbers below are obtained from crosstabs in 01_prepare_data.do (after summary statistics)"
*in actual sample
local a1mms=
local a0mgimp=
local a1mgimp=

cap log close
log using "`lpath'/acs_mc4.txt", text replace
use "`dpath'/analysis_acs.dta", clear

foreach samp in pikd {
matrix drop _all

if "`samp'"=="full" {
local sample "Full Sample"
local if ""
local imp "imp"
local weight wgt
}
if "`samp'"=="nimp" {
local sample "Non-Imputed Sample"
local if "& `impute'==0"
local imp "nimp"
local weight wgt
}

if "`samp'"=="pikd" {
local sample "Piked Sample"
local if "& onepik==1"
local imp "imp"
local weight "`adjwgt'"
}

if "`samp'"=="pikdnimp" {
local sample "Non-Imputed and Piked Sample"
local if "& `impute'==0 & onepik==1"
local imp "nimp"
local weight "`adjwgt'"
}

*run MC study
gen mr_admin=`admin'
gen rand=.
gen adminrecip_mc=.
gen adminnorecip_mc=.
gen noacsfs_mc=.
gen me_mc=.

*get "true" values
*Probit on administrative data
probit `admin' `rec' [pw=`adjwgt'] if pik_b2xpovsamp==1
mat def ad=e(b)
mat coleq ad=Probit
mat inithp=(ad,`a0mg`imp'',`a1mg`imp'')
mat initcl=(ad,`a0mg`imp'',`a0mg`imp'',`a1mg`imp'',`a1mg`imp'')

*ratios of coef
mat def ratad=(nullmat(ratad)\ad[1,1..(colsof(ad)-1)]/ad[1,2])
*margins
margins, dydx(_all) post
mat def mfad=e(b)

*LPM on administrative data
reg `admin' `rec' [pw=`adjwgt'] if pik_b2xpovsamp==1
mat def lpma=e(b)
*ratios of coef
mat def ratlpma=(nullmat(ratlpma)\lpma[1,1..(colsof(lpma)-1)]/lpma[1,2])

local i=1
while `i'<=`iter' {
if mod(`i',10)==0 di "iteration `i'"

***setup
*induce random misreporting
*qui {
replace rand=runiform()
replace mr_admin=`admin'
replace mr_admin=1 if `admin'==0 & rand<`a0mg`imp''
replace mr_admin=0 if `admin'==1 & rand<`a1mg`imp''

replace adminrecip_mc=0
replace adminrecip_mc=1 if pik_b2xpovsamp==1 & `admin'==1

replace adminnorecip_mc=0
replace adminnorecip_mc=1 if pik_b2xpovsamp==1 & `admin'==0

replace noacsfs_mc=1 if mr_admin==0
replace noacsfs_mc=0 if mr_admin==1

replace me_mc=mr_admin-`admin' if pik_b2xpovsamp==1

***run models
*Probit on Survey data
probit mr_admin `rec' [pw=`weight'] if b2xpovsamp==1 `if'
mat def a=e(b)
*ratios of coefficients (ratio to 2nd coef)
capture mat def rat=(nullmat(rat)\a[1,1..(colsof(a)-1)]/a[1,2])
if _rc!=0 mat def failure=(nullmat(failure)\(`i',2,_rc))

****LPM
*uncorrected LPM
reg mr_admin `rec' [pw=`weight'] if b2xpovsamp==1 `if'
mat def a=e(b)
*ratios of coefficients (ratio to 2nd coef)
capture mat def lpmrat=(nullmat(lpmrat)\a[1,1..(colsof(a)-1)]/a[1,2])
if _rc!=0 mat def failure=(nullmat(failure)\(`i',12,_rc))
local i=`i'+1
*}
}
*show failures
capture noisily mat list failure

*ratios
local i=rowsof(rat)
di "Successful iterations rat: " `i'
mata: rat_cr=select(st_matrix("rat"),(rowsum(abs(st_matrix("rat"):-st_matrix("ratad")[1...,1..cols(st_matrix("rat"))]):>=5:*abs(st_matrix("ratad")[1...,1..cols(st_matrix("rat"))])):>0))
mata: rat=st_matrix("rat")
mata: rows(rat_cr)
mata: rat_cr
mat list ratad

*lpm ratios
local i=rowsof(lpmrat)
di "Successful iterations lpmrat: " `i'
mata: lpmrat_cr=select(st_matrix("lpmrat"),(rowsum(abs(st_matrix("lpmrat"):-st_matrix("ratlpma")[1...,1..cols(st_matrix("lpmrat"))]):>=5:*abs(st_matrix("ratlpma")[1...,1..cols(st_matrix("lpmrat"))])):>0))
mata: lpmrat=st_matrix("lpmrat")
mata: rows(lpmrat_cr)
mata: lpmrat_cr
mat list ratlpma

*calculate bias and mse

*bias
capture noisily mata: st_matrix("bias_rat",colsum(rat:-st_matrix("ratad"))/rows(rat))
*mse
capture noisily mata: st_matrix("mse_rat",colsum((rat:-st_matrix("ratad")):^2)/rows(rat))

*bias
capture noisily mata: st_matrix("bias_lpmrat",colsum(lpmrat:-st_matrix("ratlpma"))/rows(lpmrat))
*mse
capture noisily mata: st_matrix("mse_lpmrat",colsum((lpmrat:-st_matrix("ratlpma")):^2)/rows(lpmrat))

*write file
file open results using tables/mc_uncacs_`samp'4.txt, write text replace
foreach x in rat lpmrat {
file write results "bias `x'"
local i=1
capture noisily {
while `i'<=colsof(bias_`x') {
local val=bias_`x'[1,`i']
file write results ", `val'" 
local i=`i'+1
}
}
file write results _n
file write results "mse `x'"
local i=1
capture noisily {
while `i'<=colsof(mse_`x') {
local val=mse_`x'[1,`i']
file write results ", `val'"
local i=`i'+1
}
}
file write results _n
}
file close results
}


**CPS
*set locals
*food stamp variable
local survey fscps
local admin fsad_cpshh

*imputation variable
local impute fsimpute

*weight 
local weight hhwgt
local adjwgt adjwt

*covariates for false negatives
local fneg "povindex age_ge50 maryld"

*covariates for false positives
local fpos "povindex age_ge50 maryld"

*cells for alpha
local a0cells fsimpute
local a1cells age_ge50

*covariates for receipt
local rec "povindex age_ge50 maryld"

di "The numbers below are obtained from crosstabs in 01_prepare_data.do (after summary statistics)"
*alphas from admin data
*in actual sample
local a1mms=
local a0mgimp=
local a1mgimp=

cap log close
log using "`lpath'/cps_mc4.txt", text replace
use "`dpath'/analysis_cps.dta", clear

foreach samp in pikd {
matrix drop _all

if "`samp'"=="full" {
local sample "Full Sample"
local if ""
local imp "imp"
local weight hhwgt
}
if "`samp'"=="nimp" {
local sample "Non-Imputed Sample"
local if "& `impute'==0"
local imp "nimp"
local weight hhwgt
}

if "`samp'"=="pikd" {
local sample "Piked Sample"
local if "& hhpiked==1"
local imp "imp"
local weight "`adjwgt'"
}

if "`samp'"=="pikdnimp" {
local sample "Non-Imputed and Piked Sample"
local if "& `impute'==0 & hhpiked==1"
local imp "nimp"
local weight "`adjwgt'"
}

*run MC study
gen mr_admin=`admin'
gen rand=.
gen adminrecip_mc=.
gen adminnorecip_mc=.
gen noacsfs_mc=.
gen me_mc=.

*get "true" values
*Probit on administrative data
probit `admin' `rec' [pw=`adjwgt'] if povindex<=200 & hhlder==1 & hhpiked==1
mat def ad=e(b)
mat coleq ad=Probit
mat inithp=(ad,`a0mg`imp'',`a1mg`imp'')
mat initcl=(ad,`a0mg`imp'',`a0mg`imp'',`a1mg`imp'',`a1mg`imp'')

*ratios of coef
mat def ratad=(nullmat(ratad)\ad[1,1..(colsof(ad)-1)]/ad[1,2])
*margins
margins, dydx(_all) post
mat def mfad=e(b)

*LPM on administrative data
reg `admin' `rec' [pw=`adjwgt'] if povindex<=200 & hhlder==1 & hhpiked==1
mat def lpma=e(b)
*ratios of coef
mat def ratlpma=(nullmat(ratlpma)\lpma[1,1..(colsof(lpma)-1)]/lpma[1,2])

local i=1
while `i'<=`iter' {
if mod(`i',10)==0 di "iteration `i'"

***setup
*induce random misreporting
*qui {
replace rand=runiform()
replace mr_admin=`admin'
replace mr_admin=1 if `admin'==0 & rand<`a0mg`imp''
replace mr_admin=0 if `admin'==1 & rand<`a1mg`imp''

replace adminrecip_mc=0
replace adminrecip_mc=1 if povindex<=200 & hhlder==1 & hhpiked==1 & `admin'==1

replace adminnorecip_mc=0
replace adminnorecip_mc=1 if povindex<=200 & hhlder==1 & hhpiked==1 & `admin'==0

replace noacsfs_mc=1 if mr_admin==0
replace noacsfs_mc=0 if mr_admin==1

replace me_mc=mr_admin-`admin' if povindex<=200 & hhlder==1 & hhpiked==1

***run models
*Probit on Survey data
probit mr_admin `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if'
mat def a=e(b)

*ratios of coefficients (ratio to 2nd coef)
capture mat def rat=(nullmat(rat)\a[1,1..(colsof(a)-1)]/a[1,2])
if _rc!=0 mat def failure=(nullmat(failure)\(`i',2,_rc))

****LPM
*uncorrected LPM
reg mr_admin `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if'
mat def a=e(b)
*ratios of coefficients (ratio to 2nd coef)
capture mat def lpmrat=(nullmat(lpmrat)\a[1,1..(colsof(a)-1)]/a[1,2])
if _rc!=0 mat def failure=(nullmat(failure)\(`i',12,_rc))
local i=`i'+1
*}
}

*show failures
capture noisily mat list failure

*ratios
local i=rowsof(rat)
di "Successful iterations rat: " `i'
mata: rat_cr=select(st_matrix("rat"),(rowsum(abs(st_matrix("rat"):-st_matrix("ratad")[1...,1..cols(st_matrix("rat"))]):>=5:*abs(st_matrix("ratad")[1...,1..cols(st_matrix("rat"))])):>0))
mata: rat=st_matrix("rat")
mata: rows(rat_cr)
mata: rat_cr
mat list ratad

*lpm ratios
local i=rowsof(lpmrat)
di "Successful iterations lpmrat: " `i'
mata: lpmrat_cr=select(st_matrix("lpmrat"),(rowsum(abs(st_matrix("lpmrat"):-st_matrix("ratlpma")[1...,1..cols(st_matrix("lpmrat"))]):>=5:*abs(st_matrix("ratlpma")[1...,1..cols(st_matrix("lpmrat"))])):>0))
mata: lpmrat=st_matrix("lpmrat")
mata: rows(lpmrat_cr)
mata: lpmrat_cr
mat list ratlpma

*calculate bias and mse

*bias
capture noisily mata: st_matrix("bias_rat",colsum(rat:-st_matrix("ratad"))/rows(rat))
*mse
capture noisily mata: st_matrix("mse_rat",colsum((rat:-st_matrix("ratad")):^2)/rows(rat))

*bias
capture noisily mata: st_matrix("bias_lpmrat",colsum(lpmrat:-st_matrix("ratlpma"))/rows(lpmrat))
*mse
capture noisily mata: st_matrix("mse_lpmrat",colsum((lpmrat:-st_matrix("ratlpma")):^2)/rows(lpmrat))

*write file
file open results using tables/mc_unccps_`samp'4.txt, write text replace
foreach x in rat lpmrat {
file write results "bias `x'"
local i=1
capture noisily {
while `i'<=colsof(bias_`x') {
local val=bias_`x'[1,`i']
file write results ", `val'" 
local i=`i'+1
}
}
file write results _n
file write results "mse `x'"
local i=1
capture noisily {
while `i'<=colsof(mse_`x') {
local val=mse_`x'[1,`i']
file write results ", `val'"
local i=`i'+1
}
}
file write results _n
}
file close results
}

