****NOTE: This program computes the estimators we compare in part 4.2 of "Misclassification in Binary Choice Models"

clear *
cap log close
set maxiter 500
cd ..
adopath+prog

***ACS

*set locals
local dpath data
local lpath logs

*food stamp variable
local survey acsfs
local admin fsrecip

*imputation variable
local impute fsimpute

*weight 
local weight wgt
local adjwgt total_wgt

*covariates for false negatives
local fneg "hpovindex povindex_2 povindex_3 age_ge50 maryld"

*covariates for false positives
local fpos "hpovindex povindex_2 age_ge50 maryld"

*cells for alpha
local a0cells fsimpute
local a1cells age_ge50

*covariates for receipt
local rec "hpovindex age_ge50 maryld"

di "The numbers below are obtained from crosstabs in 01_prepare_data.do (after summary statistics)"
*in actual sample
local a1mms=
local a0mgimp=
local a1mgimp=


*run stuff
cap log close
log using "`lpath'/acs_cor.txt", text replace
use "`dpath'/analysis_acs.dta", clear

foreach samp in pikd {

if "`samp'"=="full" {
local sample "Full Sample"
local if ""
local imp "imp"
local weight wgt
}
if "`samp'"=="nimp" {
local sample "Non-Imputed Sample"
local if "& `impute'==0"
local imp "nimp"
local weight wgt
}

if "`samp'"=="pikd" {
local sample "Piked Sample"
local if "& onepik==1"
local imp "imp"
local weight "`adjwgt'"
}

if "`samp'"=="pikdnimp" {
local sample "Non-Imputed and Piked Sample"
local if "& `impute'==0 & onepik==1"
local imp "nimp"
local weight "`adjwgt'"
}

*get probabilities of fneg/fpos to integrate them out
*fneg
probit noacsfs `fneg' [pw=`weight'] if adminrecip==1 `if'
predict pr_fn, pr
sum pr_fn, d
outreg2 using tables/mr_acscoef_`samp'_cor, excel replace title(The Determinants of Misreporting, Probit Coeff, 2001 ACS, `sample') ctitle(False Negatives 2 Step) bdec(4) sdec(4) noaster se o label(insert)

*fpos
probit `survey' `fpos' [pw=`weight'] if adminnorecip==1 `if'
predict pr_fp, pr
sum pr_fp, d
outreg2 using tables/mr_acscoef_`samp'_cor, excel append ctitle(False Positives 2 Step) bdec(4) sdec(4) noaster se o label(insert)

*run admin model to get starting values
probit `admin' `rec' [pw=`adjwgt'] if pik_b2xpovsamp==1
mat def iv=e(b)
mat coleq iv=Probit

*Probit on Survey data
di "Probit for receipt in survey, `sample'"
probit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 `if'
estimates store acs
outreg2 using tables/determinants_acscoef_`samp'_cor, excel replace title(The Determinants of Food Stamp Receipt, Probit Coeff, 2001 ACS, `sample') ctitle(Probit) bdec(4) sdec(4) noaster se o label(insert)
mat def sv=e(b)
mat def varsv=e(V)

*ratios of coefficients (ratio to 2nd coef)
mat def rat=sv[1,1..(colsof(sv)-1)]/sv[1,2]
local n=e(N)
local k=e(k)
local k=`n'-`k'
gen spl=e(sample)
mat def varrat=I(colsof(rat))
local names : colnames rat
matrix rownames varrat=`names'
matrix colnames varrat=`names'
local names : coleq rat
matrix roweq varrat=`names'
matrix coleq varrat=`names'

*scaled up marginal effects
margins, dydx(_all) post
outreg2 using tables/determinants_acs_`samp'_cor, excel replace title(The Determinants of Food Stamp Receipt, Avg Der, 2001 ACS, `sample') ctitle(Probit) bdec(4) sdec(4) noaster se o label(insert)
mat def mfsv=e(b)
mat def sc=mfsv/(1-`a0mg`imp''-`a1mg`imp'')
mat def varmfsv=e(V)
mat def varsc=varmfsv/((1-`a0mg`imp''-`a1mg`imp'')^2)
ereturn post sc varsc, depname(`survey') obs(`n') esample(spl) dof(`k')
gen spl=e(sample)
mat def sc=e(b)
mat def varsc=e(V)
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(Scaled Up MF) bdec(4) sdec(4) noaster se o label(insert)
outreg2 using tables/determinants_acs_`samp'_cor, excel append ctitle(Scaled Up MF) bdec(4) sdec(4) noaster se o label(insert)


*repost ratios of coefficients
ereturn post rat varrat, depname(`survey') obs(`n') esample(spl) dof(`k')
mat def rat=e(b)
mat def varratad=e(V)
mat coleq varratad=""
mat roweq varratad=""
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(Coef Ratios) bdec(4) sdec(4) noaster se o label(insert)


*Hausman Probit
di "Hausman Probit for receipt in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 `if', p maxopts(difficult) modelopts(technique(dfp bfgs nr bhhh))
capture noisily {
estimates store acs
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(Hausman Probit) bdec(4) sdec(4) noaster se o label(insert)
mat def hp=e(b)
mat def varhp=e(V)

margins, dydx(_all) post
outreg2 using tables/determinants_acs_`samp'_cor, excel append ctitle(Hausman Probit) bdec(4) sdec(4) noaster se o label(insert)
}

*Hausman Probit with alpha0=0 and alpha1 from Meyer, Mok, Sullivan
di "Hausman Probit with alpha1 from MMS (a0=0 a1=`a1mms') for receipt in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 `if', alpha0(0) alpha1(`a1mms') p maxopts(difficult)
capture noisily {
estimates store acs
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(alpha from MMS) bdec(4) sdec(4) noaster se o label(insert)
mat def mms=e(b)
mat def varmms=e(V)


margins, dydx(_all) post
outreg2 using tables/determinants_acs_`samp'_cor, excel append ctitle(alpha from MMS) bdec(4) sdec(4) noaster se o label(insert)
}

*Hausman Probit with alphas from MG
di "Hausman Probit with alphas from MG (a0=`a0mg`imp'' a1=`a1mg`imp'') for receipt in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 `if', alpha0(`a0mg`imp'') alpha1(`a1mg`imp'') p maxopts(difficult)
capture noisily {
estimates store acs
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(alpha from MG) bdec(4) sdec(4) noaster se o label(insert)
mat def mg=e(b)
mat def varmg=e(V)

margins, dydx(_all) post
outreg2 using tables/determinants_acs_`samp'_cor, excel append ctitle(alpha from MG) bdec(4) sdec(4) noaster se o label(insert)
}

*cells for alphas
di "Hausman Probit with cells for alphas for receipt in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 `if', alpha0(`a0cells') alpha1(`a1cells') p maxopts(difficult) init(iv)
capture noisily {
estimates store acs
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(Alpha cells) bdec(4) sdec(4) noaster se o label(insert)
mat def cl=e(b)
mat def varcl=e(V)

margins `rec', dydx(`rec') post
outreg2 using tables/determinants_acs_`samp'_cor, excel append ctitle(Alpha cells) bdec(4) sdec(4) noaster se o label(insert)
}

*Predicted Probabilities
di "Hausman Probit using predicted Probabilities in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 `if', alpha0(pr_fp) alpha1(pr_fn) p
capture noisily {
estimates store acs
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(Predicted Probabilities) bdec(4) sdec(4) noaster se o label(insert)
mat def pp=e(b)
mat def varpp=e(V)

margins `rec', dydx(`rec') post
outreg2 using tables/determinants_acs_`samp'_cor, excel append ctitle(Predicted Probabilities) bdec(4) sdec(4) noaster se o label(insert)
}

*Joint estimator with no overlapp
gen tmp=runiform()
qui: sum tmp, d
gen samp=(tmp<r(p50)) if b2xpovsamp==1 `if'
recode samp (0=3)
global Samp samp
tab samp

ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 `if' [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 `if' [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
capture noisily {
estimates store acs
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(Joint, no common obs) bdec(4) sdec(4) noaster se o label(insert)
mat def jno=e(b)
mat def varjno=e(V)
}


recode samp (1=2)
tab samp
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 `if' [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 `if' [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
capture noisily {
estimates store acs
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(Joint, validated) bdec(4) sdec(4) noaster se o label(insert)
mat def jva=e(b)
mat def varjva=e(V)
}
drop tmp samp

*Probit on administrative data
di "Administrative data, Piked Sample"
probit `admin' `rec' [pw=`adjwgt'] if pik_b2xpovsamp==1
estimates store admin
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(Matched) bdec(4) sdec(4) noaster se o label(insert)
mat def ad=e(b)
mat def varad=e(V)

margins, dydx(_all) post
outreg2 using tables/determinants_acs_`samp'_cor, excel append ctitle(Matched) bdec(4) sdec(4) noaster se o label(insert)
mat def mfad=e(b)
mat def varmfad=e(V)

*add true ratios
mat def ratad=ad[1,1..(colsof(ad)-1)]/ad[1,2]
mat coleq ratad=""
local n=e(N)
local k=e(k)
local k=`n'-`k'
gen spl=e(sample)
ereturn post ratad varratad, depname(`survey') obs(`n') esample(spl) dof(`k')
mat def ratad=e(b)
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_acscoef_`samp'_cor, excel append ctitle(Admin Coef Ratios) bdec(4) sdec(4) noaster se o label(insert)

*linear probability model

*get me
gen me=`survey'-`admin' if pik_b2xpovsamp==1

di "Uncorrected LPM, `sample'"
reg `survey' `rec' [pw=`weight'] if b2xpovsamp==1 `if'
outreg2 using tables/determinants_acslpm_`samp'_cor, excel replace title(The Determinants of Food Stamp Receipt, Avg Der, 2001 ACS, LPM, `sample') ctitle(LPM) bdec(4) sdec(4) noaster se o label(insert)
mat def lpmsv=e(b)
mat def varlpmsv=e(V)

*ratios of coefficients (ratio to 2nd coef)
mat def lpmrat=lpmsv[1,1..(colsof(lpmsv)-1)]/lpmsv[1,2]
local n=e(N)
local k=e(k)
local k=`n'-`k'
gen spl=e(sample)
mat def varlpmrat=I(colsof(lpmrat))
local names : colnames lpmrat
matrix rownames varlpmrat=`names'
matrix colnames varlpmrat=`names'
local names : coleq lpmrat
matrix roweq varlpmrat=`names'
matrix coleq varlpmrat=`names'

ereturn post lpmrat varlpmrat, depname(`survey') obs(`n') esample(spl) dof(`k')
mat def lpmrat=e(b)
mat def varratlpma=e(V)
mat coleq varratlpma=""
mat roweq varratlpma=""
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_acslpm_`samp'_cor, excel append ctitle(Coef Ratios LPM) bdec(4) sdec(4) noaster se o label(insert)

*scaled up coefficients
mat def lpmsc=lpmsv[1,1..(colsof(lpmsv)-1)]/(1-`a0mg`imp''-`a1mg`imp'')
mat def varlpmsc=varlpmsv[1..(colsof(lpmsv)-1),1..(colsof(lpmsv)-1)]/((1-`a0mg`imp''-`a1mg`imp'')^2)
local n=e(N)
gen spl=e(sample)
ereturn post lpmsc varlpmsc, depname(`survey') obs(`n') esample(spl)
mat def lpmsc=e(b)
mat def varlpmsc=e(V)
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_acslpm_`samp'_cor, excel append ctitle(Scaled Up Coef LPM) bdec(4) sdec(4) noaster se o label(insert)

di "Corrected LPM, `sample'"
reg me `rec' [pw=`adjwgt'] if b2xpovsamp==1 `if'
qui: reg `survey' `rec' [iw=`weight'] if b2xpovsamp==1 `if'
estimates store acslpm
qui: reg me `rec' [iw=`adjwgt'] if b2xpovsamp==1 `if'
estimates store acsbias
suest acslpm acsbias
local k=wordcount("`rec'")+1
mat def lpmc=e(b)
mat def lpmc=lpmc[1,1..`k']-lpmc[1,`k'+2..2*`k'+1]
mat coleq lpmc=""
mat def survar=e(V)
mat def varlpmc=survar[1..`k',1..`k']+survar[`k'+2..2*`k'+1,`k'+2..2*`k'+1]-2*survar[`k'+2..2*`k'+1,1..`k']
mat coleq varlpmc=""
mat roweq varlpmc=""

local n=e(N)
gen spl=e(sample)
ereturn post lpmc varlpmc, depname(`survey') obs(`n') esample(spl)
mata: st_global("e(cmd)","regress")
mat def lpmc=e(b)
mat def varlpmc=e(V)
outreg2 using tables/determinants_acslpm_`samp'_cor, excel append ctitle(Corrected LPM) bdec(4) sdec(4) noaster se o label(insert)
drop me

di "LPM on admin data, `sample'"
reg `admin' `rec' [pw=`adjwgt'] if pik_b2xpovsamp==1
estimates store acs
outreg2 using tables/determinants_acslpm_`samp'_cor, excel append ctitle(LPM matched) bdec(4) sdec(4) noaster se o label(insert)
mat def lpma=e(b)
mat def varlpma=e(V)

*true ratios
mat def ratlpma=lpma[1,1..(colsof(lpma)-1)]/lpma[1,2]
mat coleq ratlpma=""
local n=e(N)
local k=e(k)
local k=`n'-`k'
gen spl=e(sample)
ereturn post ratlpma varratlpma, depname(`survey') obs(`n') esample(spl) dof(`k')
mat def ratlpma=e(b)
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_cpslpm_`samp'_cor, excel append ctitle(Admin Coef Ratios) bdec(4) sdec(4) noaster se o label(insert)

*Probit

local k=wordcount("`rec'")+1
*fraction closer to admin than survey
foreach coef in hp mms mg cl pp jno jva {
di "Fraction of coef (out of `k') closer to admin than survey, model `coef'"
capture noisily mata: sum((abs(st_matrix("ad")-st_matrix("sv")):>=abs(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])))/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*for scaled up marginal effects
local l=`k'-1
di "Fraction of scaled up MF (out of `l') closer to admin than survey"
capture noisily mata: sum((abs(st_matrix("mfad")-st_matrix("mfsv")):>=abs(st_matrix("mfad")-st_matrix("sc"))))/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc

*weighted distance using variance mat of admin model
mata: a=invsym(st_matrix("varad"))
foreach coef in sv hp mms mg cl pp jno jva {
di "Weighted distance to admin using admin variance, model `coef'"
capture noisily mata: (st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])*a[1..`k',1..`k']*(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])'/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*for scaled up marginal effects
di "Weighted distance of scaled up MF to admin using admin variance"
mata: a=invsym(st_matrix("varmfad"))
capture noisily mata: (st_matrix("mfad")-st_matrix("sc"))*a*(st_matrix("mfad")-st_matrix("sc"))'/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc

*for scaled up marginal effects
di "Weighted distance of survey MF to admin using admin variance"
mata: a=invsym(st_matrix("varmfad"))
capture noisily mata: (st_matrix("mfad")-st_matrix("mfsv"))*a*(st_matrix("mfad")-st_matrix("mfsv"))'/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc

*F-Stat of admin coefficients using variance mat of each model
foreach coef in sv hp mms mg cl pp jno jva ad {
di "F-Stat of admin coef using variance of model `coef'"
mata: a=invsym(st_matrix("var`coef'"))
capture noisily mata: (st_matrix("ad")*a[1..`k',1..`k']*st_matrix("ad")')/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*for scaled up marginal effects
di "F-Stat of admin MF using variance of scaled up marginal effects"
mata: a=invsym(st_matrix("varsc"))
capture noisily mata: (st_matrix("mfad")*a*st_matrix("mfad")')/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc

*for scaled up marginal effects
di "F-Stat of admin MF using variance of survey marginal effects"
mata: a=invsym(st_matrix("varmfsv"))
capture noisily mata: (st_matrix("mfad")*a*st_matrix("mfad")')/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc

*LPM
*fraction closer to admin than survey
foreach coef in lpmsc lpmc {
if "`coef'"=="lpmsc" local no=`l'
else local no=`k'
di "Fraction of coef (out of `no') closer to admin than survey, model `coef'"
capture noisily mata: sum((abs(st_matrix("lpma")[1,1..`no']-st_matrix("lpmsv")[1,1..`no']):>=abs(st_matrix("lpma")[1,1..`no']-st_matrix("`coef'")[1,1..`no'])))/strtoreal(st_local("no"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*weighted distance using variance mat of admin model
mata: a=invsym(st_matrix("varlpma"))
foreach coef in lpmsv lpmsc lpmc {
if "`coef'"=="lpmsc" local no=`l'
else local no=`k'
di "Weighted distance to admin using admin variance, model `coef'"
capture noisily mata: (st_matrix("lpma")[1,1..`no']-st_matrix("`coef'")[1,1..`no'])*a[1..`no',1..`no']*(st_matrix("lpma")[1,1..`no']-st_matrix("`coef'")[1,1..`no'])'/strtoreal(st_local("no"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*F-Stat of admin coefficients using variance mat of each model
foreach coef in lpmsv lpmsc lpmc lpma {
if "`coef'"=="lpmsc" local no=`l'
else local no=`k'
di "F-Stat of admin coef using variance of model `coef'"
mata: a=invsym(st_matrix("var`coef'"))
capture noisily mata: (st_matrix("lpma")[1,1..`no']*a[1..`no',1..`no']*st_matrix("lpma")[1,1..`no']')/strtoreal(st_local("no"))
if _rc!=0 di "Something went wrong, error code" _rc
}

drop pr_fn pr_fp
}
log close

*CPS
*set locals
*food stamp variable
local survey fscps
local admin fsad_cpshh

*imputation variable
local impute fsimpute

*weight 
local weight hhwgt
local adjwgt adjwt

*covariates for false negatives
local fneg "povindex age_ge50 maryld"

*covariates for false positives
local fpos "povindex age_ge50 maryld"

*cells for alpha
local a0cells fsimpute
local a1cells age_ge50

*covariates for receipt
local rec "povindex age_ge50 maryld"

di "The numbers below are obtained from crosstabs in 01_prepare_data.do (after summary statistics)"
*alphas from admin data
*in actual sample
local a1mms=
local a0mgimp=
local a1mgimp=


*run
cap log close
log using "`lpath'/cps_cor.txt", text replace
use "`dpath'/analysis_cps.dta", clear

foreach samp in pikd {
matrix drop _all


if "`samp'"=="full" {
local sample "Full Sample"
local if ""
local imp "imp"
local weight hhwgt
}
if "`samp'"=="nimp" {
local sample "Non-Imputed Sample"
local if "& `impute'==0"
local imp "nimp"
local weight hhwgt
}

if "`samp'"=="pikd" {
local sample "Piked Sample"
local if "& hhpiked==1"
local imp "imp"
local weight "`adjwgt'"
}

if "`samp'"=="pikdnimp" {
local sample "Non-Imputed and Piked Sample"
local if "& `impute'==0 & hhpiked==1"
local imp "nimp"
local weight "`adjwgt'"
}

*get probabilities of fneg/fpos to integrate them out
*fneg
probit noreport `fneg' [pw=`weight'] if povindex<=200 & `admin'==1 & hhlder==1 & hhpiked==1 `if'
predict pr_fn, pr
sum pr_fn, d
outreg2 using tables/mr_cpscoef_`samp'_cor, excel replace title(The Determinants of Misreporting, Probit Coeff, CPS, `sample') ctitle(False Negatives 2 Step) bdec(4) sdec(4) noaster se o label(insert)

*fpos
probit `survey' `fpos' [pw=`weight'] if povindex<=200 & `admin'==0 & hhlder==1 & hhpiked==1 `if'
predict pr_fp, pr
sum pr_fp, d
outreg2 using tables/mr_cpscoef_`samp'_cor, excel append ctitle(False Positives 2 Step) bdec(4) sdec(4) noaster se o label(insert)

*run admin model to get starting values
qui: probit `admin' `rec' [pw=`adjwgt'] if povindex<=200 & hhpiked==1  & hhlder==1
mat def iv=e(b)
mat coleq iv=Probit

*Probit on Survey data
di "Probit for receipt in survey, `sample'"
probit `survey' `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if'
estimates store cps
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel replace title(The Determinants of Food Stamp Receipt, Probit Coeff, CPS, `sample') ctitle(Probit) bdec(4) sdec(4) noaster se o label(insert)
mat def sv=e(b)
mat def varsv=e(V)

*ratios of coefficients (ratio to 2nd coef)
mat def rat=sv[1,1..(colsof(sv)-1)]/sv[1,2]
local n=e(N)
local k=e(k)
local k=`n'-`k'
gen spl=e(sample)
mat def varrat=I(colsof(rat))
local names : colnames rat
matrix rownames varrat=`names'
matrix colnames varrat=`names'
local names : coleq rat
matrix roweq varrat=`names'
matrix coleq varrat=`names'


*scaled up marginal effects
margins, dydx(_all) post
outreg2 using tables/determinants_cps_`samp'_cor, excel replace title(The Determinants of Food Stamp Receipt, Avg Der, 2001 CPS, `sample') ctitle(Probit) bdec(4) sdec(4) noaster se o label(insert)
mat def mfsv=e(b)
mat def sc=mfsv/(1-`a0mg`imp''-`a1mg`imp'')
mat def varmfsv=e(V)
mat def varsc=varmfsv/((1-`a0mg`imp''-`a1mg`imp'')^2)
ereturn post sc varsc, depname(`survey') obs(`n') esample(spl) dof(`k')
gen spl=e(sample)
mat def sc=e(b)
mat def varsc=e(V)
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(Scaled Up MF) bdec(4) sdec(4) noaster se o label(insert)
outreg2 using tables/determinants_cps_`samp'_cor, excel append ctitle(Scaled Up MF) bdec(4) sdec(4) noaster se o label(insert)


*repost ratios of coefficients
ereturn post rat varrat, depname(`survey') obs(`n') esample(spl) dof(`k')
mat def rat=e(b)
mat def varratad=e(V)
mat coleq varratad=""
mat roweq varratad=""
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(Coef Ratios) bdec(4) sdec(4) noaster se o label(insert)


*Hausman Probit
di "Hausman Probit for receipt in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', p maxopts(difficult) modelopts(technique(dfp bfgs nr bhhh))
capture noisily {
estimates store cps
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(Hausman Probit) bdec(4) sdec(4) noaster se o label(insert)
mat def hp=e(b)
mat def varhp=e(V)

margins, dydx(_all) post
outreg2 using tables/determinants_cps_`samp'_cor, excel append ctitle(Hausman Probit) bdec(4) sdec(4) noaster se o label(insert)
}

*Hausman Probit with alpha0=0 and alpha1 from Meyer, Mok, Sullivan
di "Hausman Probit with alpha1 from MMS (a0=0 a1=`a1mms') for receipt in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', alpha0(0) alpha1(`a1mms') p maxopts(difficult)
capture noisily {
estimates store cps
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(alpha from MMS) bdec(4) sdec(4) noaster se o label(insert)
mat def mms=e(b)
mat def varmms=e(V)


margins, dydx(_all) post
outreg2 using tables/determinants_cps_`samp'_cor, excel append ctitle(alpha from MMS) bdec(4) sdec(4) noaster se o label(insert)
}

*Hausman Probit with alphas from MG
di "Hausman Probit with alphas from MG (a0=`a0mg`imp'' a1=`a1mg`imp'') for receipt in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', alpha0(`a0mg`imp'') alpha1(`a1mg`imp'') p maxopts(difficult)
capture noisily {
estimates store cps
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(alpha from MG) bdec(4) sdec(4) noaster se o label(insert)
mat def mg=e(b)
mat def varmg=e(V)

margins, dydx(_all) post
outreg2 using tables/determinants_cps_`samp'_cor, excel append ctitle(alpha from MG) bdec(4) sdec(4) noaster se o label(insert)
}

*cells for alphas
di "Hausman Probit with cells for alphas for receipt in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', alpha0(`a0cells') alpha1(`a1cells') p maxopts(difficult)
capture noisily {
estimates store cps
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(Alpha cells) bdec(4) sdec(4) noaster se o label(insert)
mat def cl=e(b)
mat def varcl=e(V)

margins `rec', dydx(`rec') post
outreg2 using tables/determinants_cps_`samp'_cor, excel append ctitle(Alpha cells) bdec(4) sdec(4) noaster se o label(insert)
}

*Predicted Probabilities
di "Hausman Probit using predicted Probabilities in survey, `sample'"
mrprobit `survey' `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if', alpha0(pr_fp) alpha1(pr_fn) p init(iv)
capture noisily {
estimates store cps
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(Predicted Probabilities) bdec(4) sdec(4) noaster se o label(insert)
mat def pp=e(b)
mat def varpp=e(V)

margins `rec', dydx(`rec') post
outreg2 using tables/determinants_cps_`samp'_cor, excel append ctitle(Predicted Probabilities) bdec(4) sdec(4) noaster se o label(insert)
}

*Joint estimator with no overlapp
gen tmp=runiform()
qui: sum tmp, d
gen samp=(tmp<r(p50)) if povindex<=200 & hhlder==1 `if'
recode samp (0=3)
global Samp samp
tab samp

ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if povindex<=200 & hhlder==1 `if' [pw=`weight'], missing
ml search
ml init iv
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if povindex<=200 & hhlder==1 `if' [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
ml init iv
capture noisily ml maximize, difficult
}
capture noisily {
estimates store cps
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(Joint, no common obs) bdec(4) sdec(4) noaster se o label(insert)
mat def jno=e(b)
mat def varjno=e(V)
}


recode samp (1=2)
tab samp
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if povindex<=200 & hhlder==1 `if' [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if povindex<=200 & hhlder==1 `if' [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
capture noisily {
estimates store cps
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(Joint, validated) bdec(4) sdec(4) noaster se o label(insert)
mat def jva=e(b)
mat def varjva=e(V)
}
drop tmp samp

*Probit on administrative data
di "Administrative data, Piked Sample"
probit `admin' `rec' [pw=`adjwgt'] if povindex<=200 & hhpiked==1  & hhlder==1
estimates store admin
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(Matched) bdec(4) sdec(4) noaster se o label(insert)
mat def ad=e(b)
mat def varad=e(V)

margins, dydx(_all) post
outreg2 using tables/determinants_cps_`samp'_cor, excel append ctitle(Matched) bdec(4) sdec(4) noaster se o label(insert)
mat def mfad=e(b)
mat def varmfad=e(V)

*true ratios
mat def ratad=ad[1,1..(colsof(ad)-1)]/ad[1,2]
mat coleq ratad=""
local n=e(N)
local k=e(k)
local k=`n'-`k'
gen spl=e(sample)
ereturn post ratad varratad, depname(`survey') obs(`n') esample(spl) dof(`k')
mat def ratad=e(b)
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_cpscoef_`samp'_cor, excel append ctitle(Admin Coef Ratios) bdec(4) sdec(4) noaster se o label(insert)

*linear probability model

*get me
gen me=`survey'-`admin' if povindex<=200 & hhpiked==1  & hhlder==1

di "Uncorrected LPM, `sample'"
reg `survey' `rec' [pw=`weight'] if povindex<=200 & hhlder==1 `if'
outreg2 using tables/determinants_cpslpm_`samp'_cor, excel replace title(The Determinants of Food Stamp Receipt, Avg Der, CPS, LPM, `sample') ctitle(LPM) bdec(4) sdec(4) noaster se o label(insert)
mat def lpmsv=e(b)
mat def varlpmsv=e(V)

*ratios of coefficients (ratio to 2nd coef)
mat def lpmrat=lpmsv[1,1..(colsof(lpmsv)-1)]/lpmsv[1,2]
local n=e(N)
local k=e(k)
local k=`n'-`k'
gen spl=e(sample)
mat def varlpmrat=I(colsof(lpmrat))
local names : colnames lpmrat
matrix rownames varlpmrat=`names'
matrix colnames varlpmrat=`names'
local names : coleq lpmrat
matrix roweq varlpmrat=`names'
matrix coleq varlpmrat=`names'

ereturn post lpmrat varlpmrat, depname(`survey') obs(`n') esample(spl) dof(`k')
mat def lpmrat=e(b)
mat def varratlpma=e(V)
mat coleq varratlpma=""
mat roweq varratlpma=""
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_cpslpm_`samp'_cor, excel append ctitle(Coef Ratios LPM) bdec(4) sdec(4) noaster se o label(insert)

*scaled up coefficients
mat def lpmsc=lpmsv[1,1..(colsof(lpmsv)-1)]/(1-`a0mg`imp''-`a1mg`imp'')
mat def varlpmsc=varlpmsv[1..(colsof(lpmsv)-1),1..(colsof(lpmsv)-1)]/((1-`a0mg`imp''-`a1mg`imp'')^2)
local n=e(N)
gen spl=e(sample)
ereturn post lpmsc varlpmsc, depname(`survey') obs(`n') esample(spl)
mat def lpmsc=e(b)
mat def varlpmsc=e(V)
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_cpslpm_`samp'_cor, excel append ctitle(Scaled Up Coef LPM) bdec(4) sdec(4) noaster se o label(insert)

di "Corrected LPM, `sample'"
reg me `rec' [pw=`adjwgt'] if povindex<=200 & hhlder==1 `if'
qui: reg `survey' `rec' [iw=`weight'] if povindex<=200 & hhlder==1 `if'
estimates store cpslpm
qui: reg me `rec' [iw=`adjwgt'] if povindex<=200 & hhlder==1 `if'
estimates store cpsbias
suest cpslpm cpsbias
local k=wordcount("`rec'")+1
mat def lpmc=e(b)
mat def lpmc=lpmc[1,1..`k']-lpmc[1,`k'+2..2*`k'+1]
mat coleq lpmc=""
mat def survar=e(V)
mat def varlpmc=survar[1..`k',1..`k']+survar[`k'+2..2*`k'+1,`k'+2..2*`k'+1]-2*survar[`k'+2..2*`k'+1,1..`k']
mat coleq varlpmc=""
mat roweq varlpmc=""

local n=e(N)
gen spl=e(sample)
ereturn post lpmc varlpmc, depname(`survey') obs(`n') esample(spl)
mata: st_global("e(cmd)","regress")
mat def lpmc=e(b)
mat def varlpmc=e(V)
outreg2 using tables/determinants_cpslpm_`samp'_cor, excel append ctitle(Corrected LPM) bdec(4) sdec(4) noaster se o label(insert)
drop me

di "LPM on admin data, `sample'"
reg `admin' `rec' [pw=`adjwgt'] if povindex<=200 & hhpiked==1  & hhlder==1
estimates store cps
outreg2 using tables/determinants_cpslpm_`samp'_cor, excel append ctitle(LPM matched) bdec(4) sdec(4) noaster se o label(insert)
mat def lpma=e(b)
mat def varlpma=e(V)

*true ratios
mat def ratlpma=lpma[1,1..(colsof(lpma)-1)]/lpma[1,2]
mat coleq ratlpma=""
local n=e(N)
local k=e(k)
local k=`n'-`k'
gen spl=e(sample)
ereturn post ratlpma varratlpma, depname(`survey') obs(`n') esample(spl) dof(`k')
mat def ratlpma=e(b)
mata: st_global("e(cmd)","regress")
outreg2 using tables/determinants_cpslpm_`samp'_cor, excel append ctitle(Admin Coef Ratios) bdec(4) sdec(4) noaster se o label(insert)


*Probit

local k=wordcount("`rec'")+1
*fraction closer to admin than survey
foreach coef in hp mms mg cl pp jno jva {
di "Fraction of coef (out of `no') closer to admin than survey, model `coef'"
capture noisily mata: sum((abs(st_matrix("ad")-st_matrix("sv")):>=abs(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])))/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*for scaled up marginal effects
local l=`k'-1
di "Fraction of scaled up MF (out of `l') closer to admin than survey"
capture noisily mata: sum((abs(st_matrix("mfad")-st_matrix("mfsv")):>=abs(st_matrix("mfad")-st_matrix("sc"))))/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc

*weighted distance using variance mat of admin model
mata: a=invsym(st_matrix("varad"))
foreach coef in sv hp mms mg cl pp jno jva {
di "Weighted distance to admin using admin variance, model `coef'"
capture noisily mata: (st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])*a[1..`k',1..`k']*(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])'/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*for scaled up marginal effects
di "Weighted distance of scaled up MF to admin using admin variance"
mata: a=invsym(st_matrix("varmfad"))
capture noisily mata: (st_matrix("mfad")-st_matrix("sc"))*a*(st_matrix("mfad")-st_matrix("sc"))'/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc

*for scaled up marginal effects
di "Weighted distance of survey MF to admin using admin variance"
mata: a=invsym(st_matrix("varmfad"))
capture noisily mata: (st_matrix("mfad")-st_matrix("mfsv"))*a*(st_matrix("mfad")-st_matrix("mfsv"))'/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc

*F-Stat of admin coefficients using variance mat of each model
foreach coef in sv hp mms mg cl pp jno jva ad {
di "F-Stat of admin coef using variance of model `coef'"
mata: a=invsym(st_matrix("var`coef'"))
capture noisily mata: (st_matrix("ad")*a[1..`k',1..`k']*st_matrix("ad")')/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*for scaled up marginal effects
di "F-Stat of admin MF using variance of scaled up marginal effects"
mata: a=invsym(st_matrix("varsc"))
capture noisily mata: (st_matrix("mfad")*a*st_matrix("mfad")')/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc

*for scaled up marginal effects
di "F-Stat of admin MF using variance of survey marginal effects"
mata: a=invsym(st_matrix("varmfsv"))
capture noisily mata: (st_matrix("mfad")*a*st_matrix("mfad")')/strtoreal(st_local("l"))
if _rc!=0 di "Something went wrong, error code" _rc


*LPM
*fraction closer to admin than survey
foreach coef in lpmsc lpmc {
if "`coef'"=="lpmsc" local no=`l'
else local no=`k'
di "Fraction of coef (out of `no') closer to admin than survey, model `coef'"
capture noisily mata: sum((abs(st_matrix("lpma")[1,1..`no']-st_matrix("lpmsv")[1,1..`no']):>=abs(st_matrix("lpma")[1,1..`no']-st_matrix("`coef'")[1,1..`no'])))/strtoreal(st_local("no"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*weighted distance using variance mat of admin model
mata: a=invsym(st_matrix("varlpma"))
foreach coef in lpmsv lpmsc lpmc {
if "`coef'"=="lpmsc" local no=`l'
else local no=`k'
di "Weighted distance to admin using admin variance, model `coef'"
capture noisily mata: (st_matrix("lpma")[1,1..`no']-st_matrix("`coef'")[1,1..`no'])*a[1..`no',1..`no']*(st_matrix("lpma")[1,1..`no']-st_matrix("`coef'")[1,1..`no'])'/strtoreal(st_local("no"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*F-Stat of admin coefficients using variance mat of each model
foreach coef in lpmsv lpmsc lpmc lpma {
if "`coef'"=="lpmsc" local no=`l'
else local no=`k'
di "F-Stat of admin coef using variance of model `coef'"
mata: a=invsym(st_matrix("var`coef'"))
capture noisily mata: (st_matrix("lpma")[1,1..`no']*a[1..`no',1..`no']*st_matrix("lpma")[1,1..`no']')/strtoreal(st_local("no"))
if _rc!=0 di "Something went wrong, error code" _rc
}

drop pr_fn pr_fp
}
log close

