****NOTE: This program bootstraps the SEs for the predicted probabilities estimator in part 4.2 of "Misclassification in Binary Choice Models"

*bootstrap SEs for PP
clear *
cap log close
set maxiter 250
set matsize 1000
cd ..
adopath+prog
local iter=500

local dpath data
local lpath logs

*ACS
mat drop _all
*food stamp variable
local survey acsfs
local admin fsrecip

*weight 
local weight wgt
local adjwgt total_wgt

*covariates for false negatives
local fneg "hpovindex povindex_2 povindex_3 age_ge50 maryld"

*covariates for false positives
local fpos "hpovindex povindex_2 age_ge50 maryld"

*covariates for receipt
local rec "hpovindex age_ge50 maryld"

cap log close
log using "`lpath'/pp_bs.txt", text replace

*create dataset with only obs in analysis
use "`dpath'/analysis_acs.dta", clear
keep if b2xpovsamp==1 & onepik==1
save "`dpath'/acs_bs_pp.dta", replace

local i=1
while `i'<=`iter' {
use "`dpath'/acs_bs_pp.dta", clear
*resample
bsample 

*get probabilities of fneg/fpos to integrate them out
*fneg
probit noacsfs `fneg' [pw=total_wgt] if adminrecip==1
predict pr_fn, pr

*fpos
probit `survey' `fpos' [pw=total_wgt] if adminnorecip==1
predict pr_fp, pr

*run model
capture noisily mrprobit `survey' `rec' [pw=total_wgt], alpha0(pr_fp) alpha1(pr_fn)
if _rc==0 & e(converged)==1 capture noisily mat def pp=(nullmat(pp)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',_rc))
local i=`i'+1
}
mat list pp
capture mat list failure
local i=rowsof(pp)
di "Suc. Iterations: " `i'

*get mean and SD
mata: a=meanvariance(st_matrix("pp"))
di "Means, ACS"
mata: a[1,1...]

di "SDs, ACS"
mata: sqrt(diagonal(a[2..rows(a),1...])')
mata: varpp=a[2..rows(a),1...]

*tests for pp model
use "`dpath'/analysis_acs.dta", clear
probit `admin' `rec' [pw=total_wgt] if pik_b2xpovsamp==1
mat def ad=e(b)
mat def varad=e(V)

probit `survey' `rec' [pw=total_wgt] if b2xpovsamp==1 & onepik==1
mat def sv=e(b)
probit noacsfs `fneg' [pw=total_wgt] if adminrecip==1
predict pr_fn, pr
probit `survey' `fpos' [pw=total_wgt] if adminnorecip==1
predict pr_fp, pr
mrprobit `survey' `rec' [pw=total_wgt] if b2xpovsamp==1 & onepik==1, alpha0(pr_fp) alpha1(pr_fn)
mat def pp=e(b)

local k=wordcount("`rec'")+1
di "Fraction of coef (out of `k') closer to admin than survey, model pp"
capture noisily mata: sum((abs(st_matrix("ad")-st_matrix("sv")):>=abs(st_matrix("ad")-st_matrix("pp")[1,1..`k'])))/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc

di "Weighted distance to admin using admin variance, model `coef'"
mata: a=invsym(st_matrix("varad"))
capture noisily mata: (st_matrix("ad")-st_matrix("pp")[1,1..`k'])*a[1..`k',1..`k']*(st_matrix("ad")-st_matrix("pp")[1,1..`k'])'/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc

di "F-Stat of admin coef using variance of model pp"
mata: a=invsym(varpp)
capture noisily mata: (st_matrix("ad")*a[1..`k',1..`k']*st_matrix("ad")')/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc

*CPS
mat drop _all
clear mata
*food stamp variable
local survey fscps
local admin fsad_cpshh

*weight 
local weight hhwgt
local adjwgt adjwt

*covariates for false negatives
local fneg "povindex age_ge50 maryld"

*covariates for false positives
local fpos "povindex age_ge50 maryld"

*covariates for receipt
local rec "povindex age_ge50 maryld"

*create dataset with only obs in analysis
use "`dpath'/analysis_cps.dta", clear
keep if povindex<=200 & hhlder==1 & hhpiked==1
save "`dpath'/cps_bs_pp.dta", replace

local i=1
while `i'<=`iter' {
use "`dpath'/cps_bs_pp.dta", clear
*resample
bsample 

*get probabilities of fneg/fpos to integrate them out
*fneg
probit noreport `fneg' [pw=adjwt] if povindex<=200 & `admin'==1 & hhlder==1 & hhpiked==1
predict pr_fn, pr

*fpos
probit `survey' `fpos' [pw=adjwt] if povindex<=200 & `admin'==0 & hhlder==1 & hhpiked==1
predict pr_fp, pr

*run model
capture noisily mrprobit `survey' `rec' [pw=adjwt], alpha0(pr_fp) alpha1(pr_fn)
if _rc==0 & e(converged)==1 capture noisily mat def pp=(nullmat(pp)\e(b))
if _rc!=0 | e(converged)==0 mat def failure=(nullmat(failure)\(`i',_rc))
local i=`i'+1
}
mat list pp
capture mat list failure
local i=rowsof(pp)
di "Suc. Iterations: " `i'

*get mean and SD
mata: a=meanvariance(st_matrix("pp"))
di "Means, CPS"
mata: a[1,1...]

di "SDs, CPS"
mata: sqrt(diagonal(a[2..rows(a),1...])')
mata: varpp=a[2..rows(a),1...]

*tests for pp model
use "`dpath'/analysis_cps.dta", clear
probit `admin' `rec' [pw=adjwt] if povindex<=200 & hhpiked==1  & hhlder==1
mat def ad=e(b)
mat def varad=e(V)

probit `survey' `rec' [pw=adjwt] if povindex<=200 & hhpiked==1  & hhlder==1
mat def sv=e(b)
probit noreport `fneg' [pw=adjwt] if povindex<=200 & `admin'==1 & hhlder==1 & hhpiked==1
predict pr_fn, pr
probit `survey' `fpos' [pw=adjwt] if povindex<=200 & `admin'==0 & hhlder==1 & hhpiked==1
predict pr_fp, pr
mrprobit `survey' `rec' [pw=adjwt] if povindex<=200 & hhpiked==1  & hhlder==1, alpha0(pr_fp) alpha1(pr_fn)
mat def pp=e(b)

local k=wordcount("`rec'")+1
di "Fraction of coef (out of `k') closer to admin than survey, model pp"
capture noisily mata: sum((abs(st_matrix("ad")-st_matrix("sv")):>=abs(st_matrix("ad")-st_matrix("pp")[1,1..`k'])))/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc

di "Weighted distance to admin using admin variance, model `coef'"
mata: a=invsym(st_matrix("varad"))
capture noisily mata: (st_matrix("ad")-st_matrix("pp")[1,1..`k'])*a[1..`k',1..`k']*(st_matrix("ad")-st_matrix("pp")[1,1..`k'])'/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc

di "F-Stat of admin coef using variance of model pp"
mata: a=invsym(varpp)
capture noisily mata: (st_matrix("ad")*a[1..`k',1..`k']*st_matrix("ad")')/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc

cap log close

