****NOTE: This program runs the analyses that we briefly discuss in the last paragraph of part 4.2 of "Misclassification in Binary Choice Models". Additional results of these analyses can be found in earlier working paper versions of the paper.

clear *
cap log close
set maxiter 500
cd ..
adopath+prog

*set locals
local dpath data
local lpath logs

*food stamp variable
local survey acsfs
local admin fsrecip

*weight 
local weight total_wgt

*covariates for false negatives
local fneg "hpovindex povindex_2 povindex_3 age_ge50 maryld"
local fneg2 "hpovindex povindex_2 povindex_3 age_ge50"

*covariates for false positives
local fpos "hpovindex povindex_2 age_ge50 maryld"
local fpos2 "hpovindex povindex_2 age_ge50"

*covariates for receipt
local rec "hpovindex age_ge50 maryld"
local rec2 "hpovindex age_ge50"

cap log close
log using "`lpath'/extrapolation.txt", text replace

*create joint dataset
use "`dpath'/analysis_cps.dta", clear

ren povindex hpovindex
ren fscps `survey'
ren fsad_cpshh `admin'
ren adjwt `weight'
ren hhwgt wgt
ren noreport noacsfs
ren hhpiked onepik
gen b2xpovsamp=(hpovindex<=200 & hhlder==1)
gen pik_b2xpovsamp=(b2xpovsamp==1 & onepik==1)
gen adminrecip=(`admin'==1 & b2xpovsamp==1)
gen adminnorecip=(`admin'==0 & b2xpovsamp==1)

keep `admin' `survey' `weight' wgt noacsfs onepik b2xpovsamp pik_b2xpovsamp adminrecip adminnorecip hpovindex povindex_2 povindex_3 age_ge50 maryld

append using "`dpath'/analysis_acs.dta", gen(acs) keep(`admin' `survey' `weight' wgt noacsfs onepik b2xpovsamp pik_b2xpovsamp adminrecip adminnorecip hpovindex povindex_2 povindex_3 age_ge50 maryld) nol
save "`dpath'/analysis_comb.dta", replace

*test whether first stage probits are the same

*run models and predics pr
probit noacsfs `fneg' [pw=`weight'] if adminrecip==1 & acs==0
predict pr_fn_cps, pr
probit noacsfs `fneg' [pw=`weight'] if adminrecip==1 & acs==1
predict pr_fn_acs, pr


probit `survey' `fpos' [pw=`weight'] if adminnorecip==1 & acs==0
predict pr_fp_cps, pr
probit `survey' `fpos' [pw=`weight'] if adminnorecip==1 & acs==1
predict pr_fp_acs, pr

*sur, test CPS vs ACS
qui {
probit noacsfs `fneg' [iw=`weight'] if adminrecip==1 & acs==0
est store cps_fneg
probit noacsfs `fneg' [iw=`weight'] if adminrecip==1 & acs==1
est store acs_fneg
probit `survey' `fpos' [iw=`weight'] if adminnorecip==1 & acs==0
est store cps_fpos
probit `survey' `fpos' [iw=`weight'] if adminnorecip==1 & acs==1
est store acs_fpos
}
suest cps_fneg acs_fneg cps_fpos acs_fpos

*test fneg only
test [cps_fneg_noacsfs=acs_fneg_noacsfs]
*test fpos only
test [acs_fpos_acsfs =cps_fpos_acsfs ]
*joint test
test [cps_fneg_noacsfs=acs_fneg_noacsfs], a

*test MD vs IL
*ACS
qui {
probit noacsfs `fneg2' [iw=`weight'] if adminrecip==1 & acs==1 & maryld==1
est store md_fneg
probit noacsfs `fneg2' [iw=`weight'] if adminrecip==1 & acs==1 & maryld==0
est store il_fneg
probit `survey' `fpos2' [iw=`weight'] if adminnorecip==1 & acs==1 & maryld==1
est store md_fpos
probit `survey' `fpos2' [iw=`weight'] if adminnorecip==1 & acs==1 & maryld==0
est store il_fpos
}
suest md_fneg il_fneg md_fpos il_fpos

*test fneg only
test [il_fneg_noacsfs=md_fneg_noacsfs]
*test fpos only
test [il_fpos_acsfs =md_fpos_acsfs ]
*joint test
test [il_fneg_noacsfs=md_fneg_noacsfs], a

*CPS
qui {
probit noacsfs `fneg2' [iw=`weight'] if adminrecip==1 & acs==0 & maryld==1
est store md_fneg
probit noacsfs `fneg2' [iw=`weight'] if adminrecip==1 & acs==0 & maryld==0
est store il_fneg
probit `survey' `fpos' [iw=`weight'] if adminnorecip==1 & acs==0 & maryld==1
est store md_fpos
probit `survey' `fpos' [iw=`weight'] if adminnorecip==1 & acs==0 & maryld==0
est store il_fpos
}
suest md_fneg il_fneg md_fpos il_fpos

*test fneg only
test [il_fneg_noacsfs=md_fneg_noacsfs]
*test fpos only
test [il_fpos_acsfs =md_fpos_acsfs]
*joint test
test [il_fneg_noacsfs=md_fneg_noacsfs], a

*use first stage from acs for cps
*2 Step
mrprobit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 & onepik==1 & acs==0, alpha0(pr_fp_acs) alpha1(pr_fn_acs)
mat def ts_cps=e(b)
mat def varts_cps=e(V)
outreg2 using tables/extr_test, excel replace title(Testing Extrapolation, Probit Coeff) ctitle(2Step, CPS out) bdec(4) sdec(4) noaster se o label(insert)

*joint estimator without overlap
gen samp=1 if acs==1
replace samp=3 if acs==0

global Samp samp
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & onepik==1 [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & onepik==1 [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint, no common obs, CPS out) bdec(4) sdec(4) noaster se o label(insert)
mat def jn_cps=e(b)
mat def varjn_cps=e(V)

*joint estimator with overlap
replace samp=2 if samp==1

ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & onepik==1 [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & onepik==1 [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint common obs, CPS out) bdec(4) sdec(4) noaster se o label(insert)
mat def jv_cps=e(b)
mat def varjv_cps=e(V)

*get comparison statistics
*get required coefs
*admin model for CPS
probit `admin' `rec' [pw=`weight'] if pik_b2xpovsamp==1 & acs==1
mat def ad=e(b)
mat def varad=e(V)

*sv cps
probit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 & onepik==1 & acs==1
mat def sv=e(b)


local k=wordcount("`rec'")+1
foreach coef in ts_cps jn_cps jv_cps {
di "Fraction of coef (out of `k') closer to admin than survey, model `coef'"
capture noisily mata: sum((abs(st_matrix("ad")-st_matrix("sv")):>=abs(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])))/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

mata: a=invsym(st_matrix("varad"))
foreach coef in ts_cps jn_cps jv_cps {
di "Weighted distance to admin using admin variance, model `coef'"
capture noisily mata: (st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])*a*(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])'/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

foreach coef in ts_cps jn_cps jv_cps {
di "F-Stat of admin coef using variance of model `coef'"
mata: a=invsym(st_matrix("var`coef'"))
capture noisily mata: (st_matrix("ad")*a[1..`k',1..`k']*st_matrix("ad")')/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}


*use first stage from cps for acs
*2 Step
mrprobit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 & onepik==1 & acs==1, alpha0(pr_fp_cps) alpha1(pr_fn_cps)
mat def ts_acs=e(b)
mat def varts_acs=e(V)
outreg2 using tables/extr_test, excel append ctitle(2Step, ACS out) bdec(4) sdec(4) noaster se o label(insert)

*joint estimator without overlap
replace samp=1 if acs==0
replace samp=3 if acs==1


ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1  & onepik==1 [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & onepik==1 [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint, no common obs, ACS out) bdec(4) sdec(4) noaster se o label(insert)
mat def jn_acs=e(b)
mat def varjn_acs=e(V)

*joint estimator with overlap
replace samp=2 if samp==1

ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & onepik==1 [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & onepik==1 [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint common obs, ACS out) bdec(4) sdec(4) noaster se o label(insert)
mat def jv_acs=e(b)
mat def varjv_acs=e(V)

*get comparison statistics
*get required coefs
*admin model for CPS
probit `admin' `rec' [pw=`weight'] if pik_b2xpovsamp==1 & acs==0
mat def ad=e(b)
mat def varad=e(V)

*sv cps
probit `survey' `rec' [pw=`weight'] if b2xpovsamp==1 & onepik==1 & acs==0
mat def sv=e(b)


*fraction closer to admin than survey
local k=wordcount("`rec'")+1
foreach coef in ts_acs jn_acs jv_acs {
di "Fraction of coef (out of `k') closer to admin than survey, model `coef'"
capture noisily mata: sum((abs(st_matrix("ad")-st_matrix("sv")):>=abs(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])))/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

mata: a=invsym(st_matrix("varad"))
foreach coef in ts_acs jn_acs jv_acs {
di "Weighted distance to admin using admin variance, model `coef'"
capture noisily mata: (st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])*a*(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])'/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

foreach coef in ts_acs jn_acs jv_acs {
di "F-Stat of admin coef using variance of model `coef'"
mata: a=invsym(st_matrix("var`coef'"))
capture noisily mata: (st_matrix("ad")*a[1..`k',1..`k']*st_matrix("ad")')/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}


*extrapolate from IL to MD for ACS
*2 step
probit noacsfs `fneg2' [pw=`weight'] if adminrecip==1 & acs==1 & maryld==0
predict il_fneg, pr
outreg2 using tables/extr_test, excel append ctitle(FN IL ACS) bdec(4) sdec(4) noaster se o label(insert)
probit `survey' `fpos2' [pw=`weight'] if adminnorecip==1 & acs==1 & maryld==0
predict il_fpos, pr
outreg2 using tables/extr_test, excel append ctitle(FP IL ACS) bdec(4) sdec(4) noaster se o label(insert)

mrprobit `survey' `rec2' [pw=`weight'] if b2xpovsamp==1 & onepik==1 & acs==1 & maryld==1, alpha0(il_fpos) alpha1(il_fneg)
mat def ts_md=e(b)
mat def varts_md=e(V)
outreg2 using tables/extr_test, excel append ctitle(2Step ACS MD out) bdec(4) sdec(4) noaster se o label(insert)

*joint without overlap
replace samp=.
replace samp=1 if acs==1 & maryld==0
replace samp=3 if acs==1 & maryld==1

ml model lf mrprjlik (Probit: `survey'=`rec2') (FP: `admin'=`fpos2') (FN: `admin'=`fneg2') if b2xpovsamp==1 & onepik==1 & acs==1 [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec2') (FP: `admin'=`fpos2') (FN: `admin'=`fneg2') if b2xpovsamp==1 & onepik==1 & acs==1 [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint, no common obs, MD out) bdec(4) sdec(4) noaster se o label(insert)
mat def jn_md=e(b)
mat def varjn_md=e(V)

*joint with overlap
replace samp=2 if samp==1

ml model lf mrprjlik (Probit: `survey'=`rec2') (FP: `admin'=`fpos2') (FN: `admin'=`fneg2') if b2xpovsamp==1 & onepik==1 & acs==1 [pw=`weight'], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec2') (FP: `admin'=`fpos2') (FN: `admin'=`fneg2') if b2xpovsamp==1 & onepik==1 & acs==1 [pw=`weight'], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint, no common obs, MD out) bdec(4) sdec(4) noaster se o label(insert)
mat def jv_md=e(b)
mat def varjv_md=e(V)

*get evaluation statistics
*get required coefs
*admin model for ACS MD
probit `admin' `rec2' [pw=`weight'] if pik_b2xpovsamp==1 & acs==1 & maryld==1
outreg2 using tables/extr_test, excel append ctitle(admin ACS MD) bdec(4) sdec(4) noaster se o label(insert)
mat def ad=e(b)
mat def varad=e(V)

*sv acs md
probit `survey' `rec2' [pw=`weight'] if b2xpovsamp==1 & onepik==1 & acs==1 & maryld==1
outreg2 using tables/extr_test, excel append ctitle(survey ACS MD) bdec(4) sdec(4) noaster se o label(insert)
mat def sv=e(b)


*fraction closer to admin than survey
local k=wordcount("`rec2'")+1
foreach coef in ts_md jn_md jv_md {
di "Fraction of coef (out of `k') closer to admin than survey, model `coef'"
capture noisily mata: sum((abs(st_matrix("ad")-st_matrix("sv")):>=abs(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])))/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

mata: a=invsym(st_matrix("varad"))
foreach coef in ts_md jn_md jv_md {
di "Weighted distance to admin using admin variance, model `coef'"
capture noisily mata: (st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])*a*(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])'/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

foreach coef in ts_md jn_md jv_md {
di "F-Stat of admin coef using variance of model `coef'"
mata: a=invsym(st_matrix("var`coef'"))
capture noisily mata: (st_matrix("ad")*a[1..`k',1..`k']*st_matrix("ad")')/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*extrapolate from piked to non-piked
*ACS
*two step
mrprobit `survey' `rec' [pw=wgt] if b2xpovsamp==1 & acs==1, alpha0(pr_fn_acs) alpha1(pr_fn_acs)
mat def ts=e(b)
mat def varts=e(V)
outreg2 using tables/extr_test, excel append ctitle(2Step ACS nonpiked) bdec(4) sdec(4) noaster se o label(insert)

*joint estimator, no overlap
egen missing=rowmiss(`rec' `fneg' `fpos' `survey')
replace samp=.
replace samp=1 if onepik==1
replace samp=3 if onepik==0

ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & acs==1 & missing==0 [pw=wgt], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & acs==1 & missing==0 [pw=wgt], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint, no common obs, ACS nonpiked) bdec(4) sdec(4) noaster se o label(insert)
mat def jn=e(b)
mat def varjn=e(V)

*common obs
replace samp=2 if samp==1
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & acs==1 & missing==0 [pw=wgt], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & acs==1 & missing==0 [pw=wgt], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint common obs, ACS nonpiked) bdec(4) sdec(4) noaster se o label(insert)
mat def jv=e(b)
mat def varjv=e(V)

*get evaluation statistics
*get required coefs
*admin model for ACS MD
probit `admin' `rec' [pw=`weight'] if pik_b2xpovsamp==1 & acs==1
mat def ad=e(b)
mat def varad=e(V)

*sv acs md
probit `survey' `rec' [pw=wgt] if b2xpovsamp==1 & acs==1
outreg2 using tables/extr_test, excel append ctitle(survey ACS all) bdec(4) sdec(4) noaster se o label(insert)
mat def sv=e(b)


*fraction closer to admin than survey
local k=wordcount("`rec'")+1
foreach coef in ts jn jv {
di "Fraction of coef (out of `k') closer to admin than survey, model `coef'"
capture noisily mata: sum((abs(st_matrix("ad")-st_matrix("sv")):>=abs(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])))/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

mata: a=invsym(st_matrix("varad"))
foreach coef in ts jn jv {
di "Weighted distance to admin using admin variance, model `coef'"
capture noisily mata: (st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])*a*(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])'/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

foreach coef in ts jn jv {
di "F-Stat of admin coef using variance of model `coef'"
mata: a=invsym(st_matrix("var`coef'"))
capture noisily mata: (st_matrix("ad")*a[1..`k',1..`k']*st_matrix("ad")')/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

*CPS
*two step
mrprobit `survey' `rec' [pw=wgt] if b2xpovsamp==1 & acs==0, alpha0(pr_fn_acs) alpha1(pr_fn_acs)
mat def ts=e(b)
mat def varts=e(V)
outreg2 using tables/extr_test, excel append ctitle(2Step CPS nonpiked) bdec(4) sdec(4) noaster se o label(insert)

*common obs
replace samp=.
replace samp=2 if onepik==1
replace samp=3 if onepik==0

ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & acs==0 & missing==0 [pw=wgt], missing
ml search
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & acs==0 & missing==0 [pw=wgt], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint common obs, CPS nonpiked) bdec(4) sdec(4) noaster se o label(insert)
mat def jv=e(b)
mat def varjv=e(V)

*joint estimator, no overlap
replace samp=1 if samp==2
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & acs==0 & missing==0 [pw=wgt], missing
ml search
ml init jv
capture noisily ml maximize
if _rc!=0 {
ml model lf mrprjlik (Probit: `survey'=`rec') (FP: `admin'=`fpos') (FN: `admin'=`fneg') if b2xpovsamp==1 & acs==0 & missing==0 [pw=wgt], missing technique(dfp bfgs nr bhhh)
ml search
capture noisily ml maximize, difficult
}
outreg2 using tables/extr_test, excel append ctitle(Joint, no common obs, CPS nonpiked) bdec(4) sdec(4) noaster se o label(insert)
mat def jn=e(b)
mat def varjn=e(V)

*get evaluation statistics
*get required coefs
*admin model for ACS MD
probit `admin' `rec' [pw=`weight'] if pik_b2xpovsamp==1 & acs==0
mat def ad=e(b)
mat def varad=e(V)

*sv acs md
probit `survey' `rec' [pw=wgt] if b2xpovsamp==1 & acs==0
outreg2 using tables/extr_test, excel append ctitle(survey CPS all) bdec(4) sdec(4) noaster se o label(insert)
mat def sv=e(b)


*fraction closer to admin than survey
local k=wordcount("`rec'")+1
foreach coef in ts jn jv {
di "Fraction of coef (out of `k') closer to admin than survey, model `coef'"
capture noisily mata: sum((abs(st_matrix("ad")-st_matrix("sv")):>=abs(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])))/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

mata: a=invsym(st_matrix("varad"))
foreach coef in ts jn jv {
di "Weighted distance to admin using admin variance, model `coef'"
capture noisily mata: (st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])*a*(st_matrix("ad")-st_matrix("`coef'")[1,1..`k'])'/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

foreach coef in ts jn jv {
di "F-Stat of admin coef using variance of model `coef'"
mata: a=invsym(st_matrix("var`coef'"))
capture noisily mata: (st_matrix("ad")*a[1..`k',1..`k']*st_matrix("ad")')/strtoreal(st_local("k"))
if _rc!=0 di "Something went wrong, error code" _rc
}

cap log close










