****NOTE: This file replicates the simulations of the bias in part 3.2 of "Misclassification in Binary Choice Models". It runs the same simulations for several other misclassification models, to skip these additional simulations, uncomment line 46.

***general setup
cap log close
log using mc_misrep4.txt, text replace
*get time
set rmsg on

*# of observations
local obs=10000

*number of iterations for MC
local iter=100
local mat=max(`iter',500)
set matsize `mat'

*number of grid points
local points=100

*maximum of misreporting for evaluating level (in %)->start at 0
local mrmax=50

*maximum of correlation/b for evaluating associatio
local bmin=-1
local bmax=1

*maximum and minimum of c (relation between m and epsilon)
local cmin=-1
local cmax=1

*coefficients of outcome model->pr0 is %of y=1, which fixes intercept
local pr0=75
local x1=0.5
local x2=0.5
local max_x1=2
local max_x2=4

*distribution of x1,x2, whether x2 is a dummy
local x1dist rnormal(0,1)
local x2dist rnormal(0.1*x1,1)
local x2dummy no

*cases to run
local cases pr_y0_unc pr_y0 level_e level_both corr_e corr_x1 corr_x2 level levelunc corr
*uncomment the line below to run only the simulation setups that were actually used in the paper
*local cases level levelunc corr

*different error distributions to loop over
local mr_edist rnormal()

*models for fp, fn or both
local mc_models both fp fn
local ptile_scale=1

*start loop over models
foreach model in `mc_models' {
	if "`model'"=="both" {
		local if_mc ""
		local ptile_scale=1
	}
	if "`model'"=="fp" {
		local if_mc "if y_true==0"
*		local ptile_scale=100/`pr0'
	}
	if "`model'"=="fn" {
		local if_mc "if y_true==1"
*		local ptile_scale=100/(100-`pr0')
	}
	*start loop over error distributions
	foreach err in `mr_edist' {
		*start loop over cases
		foreach case in  `cases' {
		clear *
		*define stuff: mr, b, x_axis
		if "`case'"=="level" {
			local x_axis "misrep1"
			local b=0.25
			local c=0
			local mr=-`mrmax'/(`points'-1)+1/`obs'
			local xtitle "Fraction Misreported"
			local x1=0.5
			local x2=0.5
			local pr0=75
		}
		if "`case'"=="levelunc" {
			local x_axis "misrep1"
			local b=0
			local c=0
			local mr=-`mrmax'/(`points'-1)+1/`obs'
			local xtitle "Fraction Misreported"
			local x1=0.5
			local x2=0.5
			local pr0=75
		}
		if "`case'"=="corr" {
			local x_axis "corr1"
			local b=`bmin'-(`bmax'-`bmin')/(`points'-1)
			local c=0
			local mr=30
			local xtitle "Correlation x1 and m"
			local x1=0.5
			local x2=0.5
			local pr0=75
		}
		if "`case'"=="corr_x1" {
			local x_axis "betax1"
			local b=0.25
			local c=0
			local mr=30
			local xtitle "Coefficient on x1 in Outcome Model"
			local x1=0
			local x2=0.5
			local pr0=75
		}
		if "`case'"=="corr_x2" {
			local x_axis "betax2"
			local b=0.25
			local c=0
			local mr=30
			local xtitle "Coefficient on x2 in Outcome Model"
			local x1=0.5
			local x2=0
			local pr0=75
		}
		if "`case'"=="level_e" {
			local x_axis "misrep1"
			local b=0
			local c=0.25
			local mr=-`mrmax'/(`points'-1)+1/`obs'
			local xtitle "Fraction Misreported"
			local x1=0.5
			local x2=0.5
			local pr0=75
		}
		if "`case'"=="level_both" {
			local x_axis "misrep1"
			local b=0.25
			local c=0.25
			local mr=-`mrmax'/(`points'-1)+1/`obs'
			local xtitle "Fraction Misreported"
			local x2=0.5
			local x1=0.5
			local pr0=75
		}
		if "`case'"=="corr_e" {
			local x_axis "corre1"
			local b=0
			local c=`cmin'-(`cmax'-`cmin')/(`points'-1)
			local mr=30
			local xtitle "Correlation epsilon and m"
			local x1=0.5
			local x2=0.5
			local pr0=75
		}
		if "`case'"=="pr_y0" {
			local x_axis "pr1"
			local b=0.25
			local c=0
			local mr=30
			local xtitle "Pr(y=1)"
			local x1=0.5
			local x2=0.5
			local pr0=0
		}
		if "`case'"=="pr_y0_unc" {
			local x_axis "pr1"
			local b=0
			local c=0
			local mr=30
			local xtitle "Pr(y=1)"
			local x1=0.5
			local x2=0.5
			local pr0=0
		}
		mat def av_true=J(`points',3,.)
		mat def av_obs=J(`points',3,.)
		mat def bias=J(`points',3,.)
		mat def bias_l=J(`points',3,.)
		mat def bias_g=J(`points',3,.)
		mat def bias_r=J(`points',3,.)
		mat def bias_ho=J(`points',3,.)
		mat def resc=J(`points',1,.)
		mat def misrep=J(`points',1,.)
		mat def corr1=J(`points',1,.)
		mat def corr2=J(`points',1,.)
		mat def coefb=J(`points',1,.)
		mat def betax=J(`points',2,.)
		mat def corre=J(`points',1,.)
		mat def rmse=J(`points',2,.)
		mat def pr1=J(`points',1,.)
	
		di "`case'"
		di "Grid Point #: "
		foreach j of numlist 1/`points' {
			qui {
				if "`case'"=="level" | "`case'"=="levelunc" | "`case'"=="level_e" | "`case'"=="level_both" local mr=`mr'+`mrmax'/(`points'-1)
				if "`case'"=="corr" local b=`b'+(`bmax'-`bmin')/(`points'-1)
				if "`case'"=="corr_x1" local x1=`x1'+`max_x1'/(`points'-1)
				if "`case'"=="corr_x2" local x2=`x2'+`max_x2'/(`points'-1)
				if "`case'"=="corr_e" local c=`c'+(`cmax'-`cmin')/(`points'-1)
				if "`case'"=="pr_y0" |"`case'"=="pr_y0_unc" local pr0=`pr0'+100/(`points'+1)
				local ptile=(100-`mr')*`ptile_scale'
				*start loop over mc iterations
				mat def true=J(`iter',3,.)
				mat def obs=J(`iter',3,.)
				mat def bx1=J(`iter',1,.)
				mat def corrx1=J(`iter',1,.)
				mat def corrx2=J(`iter',1,.)
				mat def correi=J(`iter',1,.)
				mat def mr=J(`iter',1,.)
				mata: lambda=J(`iter',3,.)
				mata: gamma=J(`iter',3,.)
				mata: rescale=J(`iter',1,.)

				if mod(`j',10)==0 n: di "`j' "
				foreach i of numlist 1/`iter' {
					***generate data
					*1. Draw X: one dummy one continuous, want correlation about 0.07
					set obs `obs'
					gen x1=`x1dist'
					gen x2=`x2dist'
					if "`x2dummy'"=="yes" replace x2=(x2>0)

					*2. Generate y: use coefficient estimates from actual data (or something close)
					gen e=rnormal()
					gen y_star=`x1'*x1+`x2'*x2+e
					_pctile y_star, p(`pr0')
					replace y_star=y_star-`r(r1)'
					gen y_true=(y_star>0)

					*3. induce misreporting: use probit model based on continuous variable
					gen m_e=`err'
					sum m_e
					replace m_e=(m_e-`r(mean)')/`r(sd)'
					gen m_star=`b'*x1+`c'*e+m_e `if_mc'
					_pctile m_star `if_mc', p(`ptile')
					gen m=(m_star>`r(r1)') `if_mc'
					replace m=0 if m==.
					gen y_obs=y_true
					replace y_obs=1-y_true if m==1


					*run probits
					probit y_obs x1 x2
					mat def obs[`i',1]=e(b)
					probit y_true x1 x2
					mat def true[`i',1]=e(b)

					*calculate components of bias
					*set up views in mata
					*X including intercept
					mata: x=st_data(.,"x1 x2")
					mata: x=(x,J(rows(x),1,1))
					*M (S=diag(M))
					mata: s=st_data(.,"m")
					*e
					mata: e=st_data(.,"e")
					*true coefficient (actual value in sample)
					mata: b=st_matrix("e(b)")
					mata: b=b'
					*x'x inverse
					mata: xxinv=invsym(xx=cross(x,x))
		

					*calculate parameters
					*lambda
					mata: lambda[`i',]=(2:*(xxinv*(x:*s)'*(x*b)))'
					*gamma
					mata: gamma[`i',]=(2:*(xxinv*(x:*s)'*e))'
					*SD of misspec error
					mata: rescale[`i',1]=sqrt(variance(e-(2:*(s:*x)*b-x*lambda[`i',]')-(2:*(s:*e)-x*gamma[`i',]')))

					*share of misreported obs
					sum m, meanonly
					mat def mr[`i',1]=`r(mean)'
		
					*extent of correlation
					mat def bx1[`i',1]=`b'
					qui corr x1 m
					mat def corrx1[`i',1]=`r(rho)'
					corr x2 m
					mat def corrx2[`i',1]=`r(rho)'
					corr e m
					mat def correi[`i',1]=`r(rho)'
		
					*clean up
					drop y* x* e m m_star m_e
				}
			}

			*get mata matrices
			mata: st_matrix("lambda",lambda)
			mata: st_matrix("gamma",gamma)
			mata: st_matrix("rescale",rescale)
			*export results of iterations?

			*average true and observed coefficients
			matrix define av_true[`j',1]=J(1,`iter',1/`iter')*true
			matrix define av_obs[`j',1]=J(1,`iter',1/`iter')*obs

			*calculate bias
			matrix define bias[`j',1]=J(1,`iter',1/`iter')*(obs-true)
			*Two options to compute components, because rescaling depends on previous biases:
			*option 1: consecutive biases. 
				*Advantage: always add up to whole bias.
				*Disadvantage: they interact, i.e. the coefficient would change by lambda/rescale if lambda were zero, not by lambda (which I'm calling the bias in this case)
			*option 2: change in coef if this bias were 0
				*advantage: makes more sense since there is no consecutive order
				*disadvantage: don't add up to full bias
			*option 1
			*average lambda
			mat def bias_l[`j',1]=-1*(J(1,`iter',1/`iter')*lambda)
			*average gamma
			mat def bias_g[`j',1]=-1*J(1,`iter',1/`iter')*gamma
			*average b_bar-(b-l-g)
			mata: st_matrix("res",mean((st_matrix("true")-lambda-gamma):*(1:/rescale:-1)))
			mat def bias_r[`j',1]=res
			mat def resc[`j',1]=J(1,`iter',1/`iter')*rescale

			*calculate "residual" bias; 
			*option 1: bias-<bias_l>-bias_g-bias_r
			*option 2: obs-b_bar 
			mat def bias_ho=bias-(bias_l+bias_g+bias_r)
		
			*calculate correlation/extent of mr
			mat def misrep[`j',1]=J(1,`iter',1/`iter')*mr
			mat def corr1[`j',1]=J(1,`iter',1/`iter')*corrx1
			mat def corr2[`j',1]=J(1,`iter',1/`iter')*corrx2
			mat def corre[`j',1]=J(1,`iter',1/`iter')*correi
			mat def coefb[`j',1]=J(1,`iter',1/`iter')*bx1
			mat def betax[`j',1]=(`x1',`x2')
			mat def pr1[`j',1]=1-`pr0'/100

			*rmse
			mata: st_matrix("res",sqrt(J(1,`iter',1/`iter')*(st_matrix("obs")[|1,1\.,2|]-(J(`iter',1,`x1'),J(`iter',1,`x2'))):^2))
			mat def rmse[`j',1]=res

		}

		di ""
		*export graphs/points
		set obs `points'
		foreach mat in misrep corr1 corr2 corre coefb av_true av_obs bias rmse bias_l bias_g bias_r bias_ho resc betax pr1 {
			svmat `mat'
		}
		export excel misrep* corr* coefb* betax* av_true* av_obs* bias* rmse* bias_l* bias_g* bias_r* bias_ho* resc* pr1* using "mc_misrep_`model'_`err'.xlsx" if _n<=`points', sheetreplace firstrow(var) sh("`case'")

		*convert biases into percentag of coefficient
		replace bias1=bias1/av_true1*100
		replace bias2=bias2/av_true2*100
		replace bias_l1=bias_l1/av_true1*100
		replace bias_g1=bias_g1/av_true1*100
		replace bias_r1=bias_r1/av_true1*100
		replace bias_ho1=bias_ho1/av_true1*100

		*make graphs: currently doing bias in x1, x2, components for x1 
		sum `x_axis', meanonly
		local min=round(r(min),0.1)
		local max=round(r(max),0.1)
		*bias x1
		twoway line bias1 `x_axis', title("Coefficient Bias for x2") subtitle("as % of true coefficient") ytitle("Bias in %") xtitle("`xtitle'") xlabel(`min'(0.1)`max')
		graph save "biasx1_`case'_`model'_`err'", replace
		graph export "biasx1_`case'_`model'_`err'.eps", replace
		*bias x2
		twoway line bias2 `x_axis', title("Coefficient Bias for x2") subtitle("as % of true coefficient") ytitle("Bias in %") xtitle("`xtitle'") xlabel(`min'(0.1)`max')
		graph save "biasx2_`case'_`model'_`err'", replace
		graph export "biasx2_`case'_`model'_`err'.eps", replace
		*both in one graph
		twoway line bias1 bias2 `x_axis', title("Coefficient Bias") subtitle("as % of true coefficient") ytitle("Bias in %") xtitle("`xtitle'") xlabel(`min'(0.1)`max') legend(label(1 "x1") label(2 "x2")) lpattern(solid dash)
		graph save "biasx_`case'_`model'_`err'", replace
		graph export "biasx_`case'_`model'_`err'.eps", replace
		*bias decomposition
		twoway line bias_l1 bias_g1 bias_r1 bias_ho1 `x_axis', title("Bias Decomposition for x1") subtitle("as % of true coefficient") ytitle("Bias in %") xtitle("`xtitle'") legend(label(1 "Lambda") label(2 "Gamma") label(3 "Rescaling") label(4 "Higher Order")) xlabel(`min'(0.1)`max')  lpattern(dash dot dash_dot solid)
		graph save "biasx1c_`case'_`model'_`err'", replace
		graph export "biasx1c_`case'_`model'_`err'.eps", replace
		

	}
}
}
log close



